@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -17,8 +27,8 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-**     of its contributors may be used to endorse or promote products derived
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
 **     from this software without specific prior written permission.
 **
 **
@@ -51,8 +61,9 @@ VideoPlayer::VideoPlayer(QWidget *parent)
     , playButton(0)
     , positionSlider(0)
 {
+    const QRect screenGeometry = QApplication::desktop()->screenGeometry(this);
     videoItem = new QGraphicsVideoItem;
-    videoItem->setSize(QSizeF(640, 480));
+    videoItem->setSize(QSizeF(screenGeometry.width() / 3, screenGeometry.height() / 2));
 
     QGraphicsScene *scene = new QGraphicsScene(this);
     QGraphicsView *graphicsView = new QGraphicsView(scene);
@@ -60,27 +71,27 @@ VideoPlayer::VideoPlayer(QWidget *parent)
     scene->addItem(videoItem);
 
     QSlider *rotateSlider = new QSlider(Qt::Horizontal);
+    rotateSlider->setToolTip(tr("Rotate Video"));
     rotateSlider->setRange(-180,  180);
     rotateSlider->setValue(0);
 
-    connect(rotateSlider, SIGNAL(valueChanged(int)),
-            this, SLOT(rotateVideo(int)));
+    connect(rotateSlider, &QAbstractSlider::valueChanged,
+            this, &VideoPlayer::rotateVideo);
 
     QAbstractButton *openButton = new QPushButton(tr("Open..."));
-    connect(openButton, SIGNAL(clicked()), this, SLOT(openFile()));
+    connect(openButton, &QAbstractButton::clicked, this, &VideoPlayer::openFile);
 
     playButton = new QPushButton;
     playButton->setEnabled(false);
     playButton->setIcon(style()->standardIcon(QStyle::SP_MediaPlay));
 
-    connect(playButton, SIGNAL(clicked()),
-            this, SLOT(play()));
+    connect(playButton, &QAbstractButton::clicked, this, &VideoPlayer::play);
 
     positionSlider = new QSlider(Qt::Horizontal);
     positionSlider->setRange(0, 0);
 
-    connect(positionSlider, SIGNAL(sliderMoved(int)),
-            this, SLOT(setPosition(int)));
+    connect(positionSlider, &QAbstractSlider::sliderMoved,
+            this, &VideoPlayer::setPosition);
 
     QBoxLayout *controlLayout = new QHBoxLayout;
     controlLayout->setMargin(0);
@@ -88,34 +99,49 @@ VideoPlayer::VideoPlayer(QWidget *parent)
     controlLayout->addWidget(playButton);
     controlLayout->addWidget(positionSlider);
 
-    QBoxLayout *layout = new QVBoxLayout;
+    QBoxLayout *layout = new QVBoxLayout(this);
     layout->addWidget(graphicsView);
     layout->addWidget(rotateSlider);
     layout->addLayout(controlLayout);
 
-    setLayout(layout);
-
     mediaPlayer.setVideoOutput(videoItem);
-    connect(&mediaPlayer, SIGNAL(stateChanged(QMediaPlayer::State)),
-            this, SLOT(mediaStateChanged(QMediaPlayer::State)));
-    connect(&mediaPlayer, SIGNAL(positionChanged(qint64)), this, SLOT(positionChanged(qint64)));
-    connect(&mediaPlayer, SIGNAL(durationChanged(qint64)), this, SLOT(durationChanged(qint64)));
+    connect(&mediaPlayer, &QMediaPlayer::stateChanged,
+            this, &VideoPlayer::mediaStateChanged);
+    connect(&mediaPlayer, &QMediaPlayer::positionChanged, this, &VideoPlayer::positionChanged);
+    connect(&mediaPlayer, &QMediaPlayer::durationChanged, this, &VideoPlayer::durationChanged);
 }
 
 VideoPlayer::~VideoPlayer()
 {
 }
 
+QSize VideoPlayer::sizeHint() const
+{
+    return (videoItem->size() * qreal(3) / qreal(2)).toSize();
+}
+
+bool VideoPlayer::isPlayerAvailable() const
+{
+    return mediaPlayer.isAvailable();
+}
 
 void VideoPlayer::openFile()
 {
-    QString fileName = QFileDialog::getOpenFileName(this, tr("Open Movie"),QDir::homePath());
+    QFileDialog fileDialog(this);
+    fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
+    fileDialog.setWindowTitle(tr("Open Movie"));
+    const QStringList supportedMimeTypes = mediaPlayer.supportedMimeTypes();
+    if (!supportedMimeTypes.isEmpty())
+        fileDialog.setMimeTypeFilters(supportedMimeTypes);
+    fileDialog.setDirectory(QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).value(0, QDir::homePath()));
+    if (fileDialog.exec() == QDialog::Accepted)
+        load(fileDialog.selectedUrls().constFirst());
+}
 
-    if (!fileName.isEmpty()) {
-        mediaPlayer.setMedia(QUrl::fromLocalFile(fileName));
-
-        playButton->setEnabled(true);
-    }
+void VideoPlayer::load(const QUrl &url)
+{
+    mediaPlayer.setMedia(url);
+    playButton->setEnabled(true);
 }
 
 void VideoPlayer::play()
