@@ -59,7 +59,7 @@ public:
 
     virtual ~QGstreamerVideoWidget() {}
 
-    QSize sizeHint() const
+    QSize sizeHint() const override
     {
         return m_nativeSize;
     }
@@ -84,7 +84,7 @@ public:
     }
 
 protected:
-    void paintEvent(QPaintEvent *)
+    void paintEvent(QPaintEvent *) override
     {
         paint_helper();
     }
