@@ -37,6 +37,7 @@
 **
 ****************************************************************************/
 
+#include <QtMultimedia/private/qtmultimediaglobal_p.h>
 #include "qgstutils_p.h"
 
 #include <QtCore/qdatetime.h>
@@ -57,7 +58,7 @@
 
 template<typename T, int N> static int lengthOf(const T (&)[N]) { return N; }
 
-#ifdef USE_V4L
+#if QT_CONFIG(linux_v4l)
 #  include <private/qcore_unix_p.h>
 #  include <linux/videodev2.h>
 #endif
@@ -123,6 +124,42 @@ static void addTagToMap(const GstTagList *list,
                     if (!map->contains("year"))
                         map->insert("year", year);
                 }
+#if GST_CHECK_VERSION(1,0,0)
+            } else if (G_VALUE_TYPE(&val) == GST_TYPE_DATE_TIME) {
+                const GstDateTime *dateTime = (const GstDateTime *)g_value_get_boxed(&val);
+                int year = gst_date_time_has_year(dateTime) ? gst_date_time_get_year(dateTime) : 0;
+                int month = gst_date_time_has_month(dateTime) ? gst_date_time_get_month(dateTime) : 0;
+                int day = gst_date_time_has_day(dateTime) ? gst_date_time_get_day(dateTime) : 0;
+                if (gst_date_time_has_time(dateTime)) {
+                    int hour = gst_date_time_get_hour(dateTime);
+                    int minute = gst_date_time_get_minute(dateTime);
+                    int second = gst_date_time_get_second(dateTime);
+                    float tz = gst_date_time_get_time_zone_offset(dateTime);
+                    QDateTime dateTime(QDate(year, month, day), QTime(hour, minute, second),
+                                       Qt::OffsetFromUTC, tz * 60 * 60);
+                    map->insert(QByteArray(tag), dateTime);
+                } else if (year > 0 && month > 0 && day > 0) {
+                    map->insert(QByteArray(tag), QDate(year,month,day));
+                }
+                if (!map->contains("year") && year > 0)
+                    map->insert("year", year);
+            } else if (G_VALUE_TYPE(&val) == GST_TYPE_SAMPLE) {
+                GstSample *sample = (GstSample *)g_value_get_boxed(&val);
+                GstCaps* caps = gst_sample_get_caps(sample);
+                if (caps && !gst_caps_is_empty(caps)) {
+                    GstStructure *structure = gst_caps_get_structure(caps, 0);
+                    const gchar *name = gst_structure_get_name(structure);
+                    if (QByteArray(name).startsWith("image/")) {
+                        GstBuffer *buffer = gst_sample_get_buffer(sample);
+                        if (buffer) {
+                            GstMapInfo info;
+                            gst_buffer_map(buffer, &info, GST_MAP_READ);
+                            map->insert(QByteArray(tag), QImage::fromData(info.data, info.size, name));
+                            gst_buffer_unmap(buffer, &info);
+                        }
+                    }
+                }
+#endif
             } else if (G_VALUE_TYPE(&val) == GST_TYPE_FRACTION) {
                 int nom = gst_value_get_fraction_numerator(&val);
                 int denom = gst_value_get_fraction_denominator(&val);
@@ -585,7 +622,7 @@ QVector<QGstUtils::CameraInfo> QGstUtils::enumerateCameras(GstElementFactory *fa
         }
     }
 
-#ifdef USE_V4L
+#if QT_CONFIG(linux_v4l)
     QDir devDir(QStringLiteral("/dev"));
     devDir.setFilter(QDir::System);
 
@@ -605,7 +642,8 @@ QVector<QGstUtils::CameraInfo> QGstUtils::enumerateCameras(GstElementFactory *fa
         memset(&input, 0, sizeof(input));
         for (; ::ioctl(fd, VIDIOC_ENUMINPUT, &input) >= 0; ++input.index) {
             if (input.type == V4L2_INPUT_TYPE_CAMERA || input.type == 0) {
-                isCamera = ::ioctl(fd, VIDIOC_S_INPUT, input.index) != 0;
+                const int ret = ::ioctl(fd, VIDIOC_S_INPUT, &input.index);
+                isCamera = (ret == 0 || errno == ENOTTY);
                 break;
             }
         }
@@ -640,7 +678,7 @@ QVector<QGstUtils::CameraInfo> QGstUtils::enumerateCameras(GstElementFactory *fa
         qt_safe_close(fd);
     }
     camerasCacheAgeTimer.restart();
-#endif // USE_V4L
+#endif // linux_v4l
 
     return devices;
 }
@@ -1394,6 +1432,40 @@ QPair<qreal, qreal> QGstUtils::structureFrameRateRange(const GstStructure *s)
     return rate;
 }
 
+typedef QMap<QString, QString> FileExtensionMap;
+Q_GLOBAL_STATIC(FileExtensionMap, fileExtensionMap)
+
+QString QGstUtils::fileExtensionForMimeType(const QString &mimeType)
+{
+    if (fileExtensionMap->isEmpty()) {
+        //extension for containers hard to guess from mimetype
+        fileExtensionMap->insert("video/x-matroska", "mkv");
+        fileExtensionMap->insert("video/quicktime", "mov");
+        fileExtensionMap->insert("video/x-msvideo", "avi");
+        fileExtensionMap->insert("video/msvideo", "avi");
+        fileExtensionMap->insert("audio/mpeg", "mp3");
+        fileExtensionMap->insert("application/x-shockwave-flash", "swf");
+        fileExtensionMap->insert("application/x-pn-realmedia", "rm");
+    }
+
+    //for container names like avi instead of video/x-msvideo, use it as extension
+    if (!mimeType.contains('/'))
+        return mimeType;
+
+    QString format = mimeType.left(mimeType.indexOf(','));
+    QString extension = fileExtensionMap->value(format);
+
+    if (!extension.isEmpty() || format.isEmpty())
+        return extension;
+
+    QRegExp rx("[-/]([\\w]+)$");
+
+    if (rx.indexIn(format) != -1)
+        extension = rx.cap(1);
+
+    return extension;
+}
+
 void qt_gst_object_ref_sink(gpointer object)
 {
 #if GST_CHECK_VERSION(0,10,24)
