@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the plugins of the Qt Toolkit.
 **
@@ -10,30 +10,28 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -59,15 +57,12 @@ QT_USE_NAMESPACE
     \inherits Item
     \preliminary
 
-    \c AudioSample is part of the \b{QtAudioEngine 1.0} module.
-
-    It can be accessed through QtAudioEngine1::AudioEngine::samples with its unique
-    name and must be defined inside AudioEngine.
+    It can be accessed through QtAudioEngine::AudioEngine::samples with its unique
+    name and must be defined inside AudioEngine or be added to it using
+    \l{QtAudioEngine::AudioEngine::addAudioSample()}{AudioEngine.addAudioSample()}
+    if AudioSample is created dynamically.
 
     \qml
-    import QtQuick 2.0
-    import QtAudioEngine 1.0
-
     Rectangle {
         color:"white"
         width: 300
@@ -86,10 +81,10 @@ QT_USE_NAMESPACE
 */
 QDeclarativeAudioSample::QDeclarativeAudioSample(QObject *parent)
     : QObject(parent)
-    , m_complete(false)
     , m_streaming(false)
     , m_preloaded(false)
     , m_soundBuffer(0)
+    , m_engine(0)
 {
 }
 
@@ -97,23 +92,11 @@ QDeclarativeAudioSample::~QDeclarativeAudioSample()
 {
 }
 
-void QDeclarativeAudioSample::classBegin()
-{
-    if (!parent() || !parent()->inherits("QDeclarativeAudioEngine")) {
-        qWarning("AudioSample must be defined inside AudioEngine!");
-        return;
-    }
-}
-
-void QDeclarativeAudioSample::componentComplete()
-{
-    if (m_name.isEmpty()) {
-        qWarning("AudioSample must have a name!");
-        return;
-    }
-    m_complete = true;
-}
+/*!
+    \qmlproperty url QtAudioEngine::AudioSample::source
 
+    This property holds the source URL of the audio sample.
+*/
 QUrl QDeclarativeAudioSample::source() const
 {
     return m_url;
@@ -121,8 +104,8 @@ QUrl QDeclarativeAudioSample::source() const
 
 void QDeclarativeAudioSample::setSource(const QUrl& url)
 {
-    if (m_complete) {
-        qWarning("AudioSample: source not changable after initialization.");
+    if (m_engine) {
+        qWarning("AudioSample: source not changeable after initialization.");
         return;
     }
     m_url = url;
@@ -133,12 +116,18 @@ bool QDeclarativeAudioSample::isStreaming() const
     return m_streaming;
 }
 
+QDeclarativeAudioEngine *QDeclarativeAudioSample::engine() const
+{
+    return m_engine;
+}
+
 /*!
-    \qmlproperty bool QtAudioEngine1::AudioSample::preloaded
+    \qmlproperty bool QtAudioEngine::AudioSample::preloaded
 
     This property indicates whether this sample needs to be preloaded or not.
-    If true, the audio engine will start loading the sample file immediately when the app started,
-    otherwise the sample will not be loaded until explicitly requested.
+    If \c true, the audio engine will start loading the sample file immediately
+    when the application starts, otherwise the sample will not be loaded until
+    explicitly requested.
 */
 
 bool QDeclarativeAudioSample::isPreloaded() const
@@ -147,7 +136,7 @@ bool QDeclarativeAudioSample::isPreloaded() const
 }
 
 /*!
-    \qmlproperty bool QtAudioEngine1::AudioSample::loaded
+    \qmlproperty bool QtAudioEngine::AudioSample::loaded
 
     This property indicates whether this sample has been loaded into memory or not.
 */
@@ -155,29 +144,28 @@ bool QDeclarativeAudioSample::isLoaded() const
 {
     if (!m_soundBuffer)
         return false;
-    return m_soundBuffer->isReady();
+    return m_soundBuffer->state() == QSoundBuffer::Ready;
 }
 
 /*!
-    \qmlmethod void QtAudioEngine1::AudioSample::load()
+    \qmlmethod void QtAudioEngine::AudioSample::load()
 
     Starts loading the sample into memory if not loaded.
 */
 void QDeclarativeAudioSample::load()
 {
-    if (isLoaded())
-        return;
     if (!m_soundBuffer) {
         m_preloaded = true;
         return;
     }
-    m_soundBuffer->load();
+    if (m_soundBuffer->state() != QSoundBuffer::Loading && m_soundBuffer->state() != QSoundBuffer::Ready)
+        m_soundBuffer->load();
 }
 
 void QDeclarativeAudioSample::setPreloaded(bool preloaded)
 {
-    if (m_complete) {
-        qWarning("AudioSample: preloaded not changable after initialization.");
+    if (m_engine) {
+        qWarning("AudioSample: preloaded not changeable after initialization.");
         return;
     }
     m_preloaded = preloaded;
@@ -185,18 +173,27 @@ void QDeclarativeAudioSample::setPreloaded(bool preloaded)
 
 void QDeclarativeAudioSample::setStreaming(bool streaming)
 {
-    if (m_complete) {
-        qWarning("AudioSample: streaming not changable after initialization.");
+    if (m_engine) {
+        qWarning("AudioSample: streaming not changeable after initialization.");
         return;
     }
     m_streaming = streaming;
 }
 
-/*!
-    \qmlproperty string QtAudioEngine1::AudioSample::name
+void QDeclarativeAudioSample::setEngine(QDeclarativeAudioEngine *engine)
+{
+    if (m_engine) {
+        qWarning("AudioSample: engine not changeable after initialization.");
+        return;
+    }
+    m_engine = engine;
+}
 
-    This property holds the name of AudioSample, must be unique among all samples and only
-    defined once.
+/*!
+    \qmlproperty string QtAudioEngine::AudioSample::name
+
+    This property holds the name of the sample, which must be unique among all
+    samples and only defined once.
 */
 QString QDeclarativeAudioSample::name() const
 {
@@ -205,8 +202,8 @@ QString QDeclarativeAudioSample::name() const
 
 void QDeclarativeAudioSample::setName(const QString& name)
 {
-    if (m_complete) {
-        qWarning("AudioSample: name not changable after initialization.");
+    if (m_engine) {
+        qWarning("AudioSample: name not changeable after initialization.");
         return;
     }
     m_name = name;
@@ -214,13 +211,14 @@ void QDeclarativeAudioSample::setName(const QString& name)
 
 void QDeclarativeAudioSample::init()
 {
+    Q_ASSERT(m_engine != 0);
+
     if (m_streaming) {
         //TODO
 
     } else {
-        m_soundBuffer =
-            qobject_cast<QDeclarativeAudioEngine*>(parent())->engine()->getStaticSoundBuffer(m_url);
-        if (m_soundBuffer->isReady()) {
+        m_soundBuffer = m_engine->engine()->getStaticSoundBuffer(m_url);
+        if (m_soundBuffer->state() == QSoundBuffer::Ready) {
             emit loadedChanged();
         } else {
             connect(m_soundBuffer, SIGNAL(ready()), this, SIGNAL(loadedChanged()));
@@ -237,9 +235,11 @@ QSoundBuffer* QDeclarativeAudioSample::soundBuffer() const
 }
 
 /*!
-    \qmlsignal QtAudioEngine1::AudioSample::onLoadedChanged()
+    \qmlsignal QtAudioEngine::AudioSample::loadedChanged()
 
-    This handler is called when \l loaded is changed
+    This signal is emitted when \l loaded is changed.
+
+    The corresponding handler is \c onLoadedChanged.
 */
 
 
