@@ -85,7 +85,7 @@ class QMultimediaDeclarativeModule : public QQmlExtensionPlugin
 
 public:
     QMultimediaDeclarativeModule(QObject *parent = 0) : QQmlExtensionPlugin(parent) { initResources(); }
-    virtual void registerTypes(const char *uri)
+    void registerTypes(const char *uri) override
     {
         Q_ASSERT(QLatin1String(uri) == QLatin1String("QtMultimedia"));
 
@@ -143,11 +143,19 @@ public:
         // 5.8 types (nothing new, re-register one of the types)
         qmlRegisterType<QSoundEffect>(uri, 5, 8, "SoundEffect");
 
+        // 5.9 types
+        qmlRegisterType<QDeclarativeAudio, 2>(uri, 5, 9, "Audio");
+        qmlRegisterType<QDeclarativeAudio, 2>(uri, 5, 9, "MediaPlayer");
+        qmlRegisterUncreatableType<QDeclarativeCameraCapture, 1>(uri, 5, 9, "CameraCapture",
+                                trUtf8("CameraCapture is provided by Camera"));
+        qmlRegisterUncreatableType<QDeclarativeCameraFlash, 1>(uri, 5, 9, "CameraFlash",
+                                trUtf8("CameraFlash is provided by Camera"));
+
         qmlRegisterType<QDeclarativeMediaMetaData>();
         qmlRegisterType<QAbstractVideoFilter>();
     }
 
-    void initializeEngine(QQmlEngine *engine, const char *uri)
+    void initializeEngine(QQmlEngine *engine, const char *uri) override
     {
         Q_UNUSED(uri);
         engine->addImageProvider("camera", new QDeclarativeCameraPreviewProvider);
