@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the plugins of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -67,11 +73,13 @@ QT_BEGIN_NAMESPACE
 /*!
     Construct a declarative camera flash object using \a parent object.
  */
-QDeclarativeCameraFlash::QDeclarativeCameraFlash(QCamera *camera, QObject *parent) :
-    QObject(parent)
+QDeclarativeCameraFlash::QDeclarativeCameraFlash(QCamera *camera, QObject *parent)
+    : QObject(parent)
 {
     m_exposure = camera->exposure();
     connect(m_exposure, SIGNAL(flashReady(bool)), this, SIGNAL(flashReady(bool)));
+    connect(camera, SIGNAL(statusChanged(QCamera::Status)),
+            this, SLOT(_q_cameraStatusChanged(QCamera::Status)));
 }
 
 QDeclarativeCameraFlash::~QDeclarativeCameraFlash()
@@ -127,6 +135,51 @@ void QDeclarativeCameraFlash::setFlashMode(QDeclarativeCameraFlash::FlashMode mo
     }
 }
 
+void QDeclarativeCameraFlash::_q_cameraStatusChanged(QCamera::Status status)
+{
+    if (status != QCamera::UnloadedStatus && status != QCamera::LoadedStatus &&
+            status != QCamera::ActiveStatus)
+        return;
+
+    emit supportedModesChanged();
+}
+
+/*!
+    \qmlproperty list<FlashMode> QtMultimedia::CameraFlash::supportedModes
+
+    This property holds the supported flash modes of the camera. If the list
+    only contains Camera.FlashOff, no flash is supported.
+
+    \code
+        Camera {
+            id: camera
+            flash {
+                onSupportedModesChanged {
+                    if (flash.supportedModes.length == 1) {
+                        // no flash supported
+                    } else {
+                        // some flash is supported
+                    }
+                }
+            }
+        }
+    \endcode
+
+    \since 5.9
+    \sa mode
+ */
+QVariantList QDeclarativeCameraFlash::supportedModes() const
+{
+    QVariantList supportedModes;
+
+    for (int i=1; i <= (int) QCameraExposure::FlashManual; i = (i << 1)) {
+        if (m_exposure->isFlashModeSupported((QCameraExposure::FlashMode) i))
+            supportedModes.append(QVariant(i));
+    }
+
+    return supportedModes;
+}
+
 /*!
     \qmlsignal QtMultimedia::CameraFlash::flashModeChanged(int)
     This signal is emitted when the \c flashMode property is changed.
