@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
@@ -10,30 +10,28 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -41,8 +39,12 @@
 
 #include "qsamplecache_p.h"
 #include "qwavedecoder_p.h"
-#include <QtNetwork>
 
+#include <QtNetwork/QNetworkAccessManager>
+#include <QtNetwork/QNetworkReply>
+#include <QtNetwork/QNetworkRequest>
+
+#include <QtCore/QDebug>
 //#define QT_SAMPLECACHE_DEBUG
 
 QT_BEGIN_NAMESPACE
@@ -123,11 +125,12 @@ QSampleCache::~QSampleCache()
     // Killing the loading thread means that no samples can be
     // deleted using deleteLater.  And some samples that had deleteLater
     // already called won't have been processed (m_staleSamples)
-    foreach (QSample* sample, m_samples)
-        delete sample;
+    for (auto it = m_samples.cbegin(), end = m_samples.cend(); it != end; ++it)
+        delete it.value();
 
-    foreach (QSample* sample, m_staleSamples)
-        delete sample; // deleting a sample does affect the m_staleSamples list, but foreach copies it
+    const auto copyStaleSamples = m_staleSamples; //deleting a sample does affect the m_staleSamples list, but we create a copy
+    for (QSample* sample : copyStaleSamples)
+        delete sample;
 
     m_networkAccessManager->deleteLater();
 }
@@ -137,8 +140,11 @@ void QSampleCache::loadingRelease()
     QMutexLocker locker(&m_loadingMutex);
     m_loadingRefCount--;
     if (m_loadingRefCount == 0) {
-        if (m_loadingThread.isRunning())
+        if (m_loadingThread.isRunning()) {
+            m_networkAccessManager->deleteLater();
+            m_networkAccessManager = nullptr;
             m_loadingThread.exit();
+        }
     }
 }
 
@@ -198,8 +204,9 @@ void QSampleCache::setCapacity(qint64 capacity)
             if (sample->m_ref == 0) {
                 unloadSample(sample);
                 it = m_samples.erase(it);
-            } else
-                it++;
+            } else {
+                ++it;
+            }
         }
     }
 
