@@ -42,6 +42,7 @@
 #include "androidsurfacetexture.h"
 #include "androidsurfaceview.h"
 #include "qandroidmultimediautils.h"
+#include "qandroidglobal.h"
 
 #include <qstringlist.h>
 #include <qdebug.h>
@@ -55,6 +56,11 @@ QT_BEGIN_NAMESPACE
 
 static const char QtCameraListenerClassName[] = "org/qtproject/qt5/android/multimedia/QtCameraListener";
 
+static QString cameraPermissionKey()
+{
+    return QStringLiteral("android.permission.CAMERA");
+}
+
 typedef QHash<int, AndroidCamera *> CameraMap;
 Q_GLOBAL_STATIC(CameraMap, cameras)
 Q_GLOBAL_STATIC(QReadWriteLock, rwLock)
@@ -196,6 +202,7 @@ public:
     Q_INVOKABLE void updatePreviewSize();
     Q_INVOKABLE bool setPreviewTexture(void *surfaceTexture);
     Q_INVOKABLE bool setPreviewDisplay(void *surfaceHolder);
+    Q_INVOKABLE void setDisplayOrientation(int degrees);
 
     Q_INVOKABLE bool isZoomSupported();
     Q_INVOKABLE int getMaxZoom();
@@ -481,6 +488,12 @@ bool AndroidCamera::setPreviewDisplay(AndroidSurfaceHolder *surfaceHolder)
     return ok;
 }
 
+void AndroidCamera::setDisplayOrientation(int degrees)
+{
+    Q_D(AndroidCamera);
+    QMetaObject::invokeMethod(d, "setDisplayOrientation", Qt::QueuedConnection, Q_ARG(int, degrees));
+}
+
 bool AndroidCamera::isZoomSupported()
 {
     Q_D(AndroidCamera);
@@ -749,6 +762,9 @@ QJNIObjectPrivate AndroidCamera::getCameraObject()
 
 int AndroidCamera::getNumberOfCameras()
 {
+    if (!requestCameraPermission())
+        return 0;
+
     return QJNIObjectPrivate::callStaticMethod<jint>("android/hardware/Camera",
                                                      "getNumberOfCameras");
 }
@@ -783,6 +799,11 @@ void AndroidCamera::getCameraInfo(int id, AndroidCameraInfo *info)
     }
 }
 
+bool AndroidCamera::requestCameraPermission()
+{
+    return qt_androidRequestPermission(cameraPermissionKey());
+}
+
 void AndroidCamera::startPreview()
 {
     Q_D(AndroidCamera);
@@ -1079,6 +1100,11 @@ bool AndroidCameraPrivate::setPreviewDisplay(void *surfaceHolder)
     return !exceptionCheckAndClear(env);
 }
 
+void AndroidCameraPrivate::setDisplayOrientation(int degrees)
+{
+    m_camera.callMethod<void>("setDisplayOrientation", "(I)V", degrees);
+}
+
 bool AndroidCameraPrivate::isZoomSupported()
 {
     QMutexLocker parametersLocker(&m_parametersMutex);
