@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -50,6 +56,10 @@ AudioMediaRecorderControl::AudioMediaRecorderControl(QObject *parent)
             this, SIGNAL(statusChanged(QMediaRecorder::Status)));
     connect(m_session, SIGNAL(actualLocationChanged(QUrl)),
             this, SIGNAL(actualLocationChanged(QUrl)));
+    connect(m_session, &AudioCaptureSession::volumeChanged,
+            this, &AudioMediaRecorderControl::volumeChanged);
+    connect(m_session, &AudioCaptureSession::mutedChanged,
+            this, &AudioMediaRecorderControl::mutedChanged);
     connect(m_session, SIGNAL(error(int,QString)),
             this, SIGNAL(error(int,QString)));
 }
@@ -85,13 +95,12 @@ qint64 AudioMediaRecorderControl::duration() const
 
 bool AudioMediaRecorderControl::isMuted() const
 {
-    return false;
+    return m_session->isMuted();
 }
 
 qreal AudioMediaRecorderControl::volume() const
 {
-    //TODO: implement muting and audio gain
-    return 1.0;
+    return m_session->volume();
 }
 
 void AudioMediaRecorderControl::setState(QMediaRecorder::State state)
@@ -101,14 +110,12 @@ void AudioMediaRecorderControl::setState(QMediaRecorder::State state)
 
 void AudioMediaRecorderControl::setMuted(bool muted)
 {
-    if (muted)
-        qWarning("Muting the audio recording is not supported.");
+    m_session->setMuted(muted);
 }
 
 void AudioMediaRecorderControl::setVolume(qreal volume)
 {
-    if (!qFuzzyCompare(volume, qreal(1.0)))
-        qWarning("Changing the audio recording volume is not supported.");
+    m_session->setVolume(volume);
 }
 
 QT_END_NAMESPACE
