@@ -55,12 +55,14 @@ static NSString* const AVF_PLAYABLE_KEY     = @"playable";
 static NSString* const AVF_STATUS_KEY       = @"status";
 
 //AVPlayer keys
-static NSString* const AVF_RATE_KEY         = @"rate";
-static NSString* const AVF_CURRENT_ITEM_KEY = @"currentItem";
+static NSString* const AVF_RATE_KEY                     = @"rate";
+static NSString* const AVF_CURRENT_ITEM_KEY             = @"currentItem";
+static NSString* const AVF_CURRENT_ITEM_DURATION_KEY    = @"currentItem.duration";
 
 static void *AVFMediaPlayerSessionObserverRateObservationContext = &AVFMediaPlayerSessionObserverRateObservationContext;
 static void *AVFMediaPlayerSessionObserverStatusObservationContext = &AVFMediaPlayerSessionObserverStatusObservationContext;
 static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMediaPlayerSessionObserverCurrentItemObservationContext;
+static void *AVFMediaPlayerSessionObserverCurrentItemDurationObservationContext = &AVFMediaPlayerSessionObserverCurrentItemDurationObservationContext;
 
 @interface AVFMediaPlayerSessionObserver : NSObject
 {
@@ -150,6 +152,7 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
     }
     if (m_player) {
         [m_player setRate:0.0];
+        [m_player removeObserver:self forKeyPath:AVF_CURRENT_ITEM_DURATION_KEY];
         [m_player removeObserver:self forKeyPath:AVF_CURRENT_ITEM_KEY];
         [m_player removeObserver:self forKeyPath:AVF_RATE_KEY];
         [m_player release];
@@ -233,7 +236,7 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
     [m_player retain];
 
     //Set the initial volume on new player object
-    if (self.session && self.session->isVolumeSupported()) {
+    if (self.session) {
         [m_player setVolume:m_session->volume() / 100.0f];
         [m_player setMuted:m_session->isMuted()];
     }
@@ -261,6 +264,12 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
                           options:NSKeyValueObservingOptionInitial | NSKeyValueObservingOptionNew
                           context:AVFMediaPlayerSessionObserverRateObservationContext];
 
+    //Observe the duration for getting the buffer state
+    [m_player addObserver:self
+                          forKeyPath:AVF_CURRENT_ITEM_DURATION_KEY
+                          options:0
+                          context:AVFMediaPlayerSessionObserverCurrentItemDurationObservationContext];
+
 }
 
 -(void) assetFailedToPrepareForPlayback:(NSError *)error
@@ -324,7 +333,7 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
                 [self assetFailedToPrepareForPlayback:playerItem.error];
 
                 if (self.session)
-                    QMetaObject::invokeMethod(m_session, "processLoadStateChange", Qt::AutoConnection);
+                    QMetaObject::invokeMethod(m_session, "processLoadStateFailure", Qt::AutoConnection);
             }
             break;
         }
@@ -343,6 +352,13 @@ static void *AVFMediaPlayerSessionObserverCurrentItemObservationContext = &AVFMe
         if (m_playerItem != newPlayerItem)
             m_playerItem = newPlayerItem;
     }
+    else if (context == AVFMediaPlayerSessionObserverCurrentItemDurationObservationContext)
+    {
+        const CMTime time = [m_playerItem duration];
+        const qint64 duration =  static_cast<qint64>(float(time.value) / float(time.timescale) * 1000.0f);
+        if (self.session)
+            QMetaObject::invokeMethod(m_session, "processDurationChange",  Qt::AutoConnection, Q_ARG(qint64, duration));
+    }
     else
     {
         [super observeValueForKeyPath:path ofObject:object change:change context:context];
@@ -380,11 +396,6 @@ AVFMediaPlayerSession::AVFMediaPlayerSession(AVFMediaPlayerService *service, QOb
     , m_state(QMediaPlayer::StoppedState)
     , m_mediaStatus(QMediaPlayer::NoMedia)
     , m_mediaStream(0)
-#ifdef Q_OS_IOS
-    , m_volumeSupported(QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_7_0)
-#else
-    , m_volumeSupported(true)
-#endif
     , m_muted(false)
     , m_tryingAsync(false)
     , m_volume(100)
@@ -479,27 +490,29 @@ void AVFMediaPlayerSession::setMedia(const QMediaContent &content, QIODevice *st
 
     if (content.isNull() || content.canonicalUrl().isEmpty()) {
         m_mediaStatus = QMediaPlayer::NoMedia;
-        m_state = QMediaPlayer::StoppedState;
-
         if (m_mediaStatus != oldMediaStatus)
             Q_EMIT mediaStatusChanged(m_mediaStatus);
 
+        m_state = QMediaPlayer::StoppedState;
         if (m_state != oldState)
             Q_EMIT stateChanged(m_state);
 
         return;
-    } else {
-
-        m_mediaStatus = QMediaPlayer::LoadingMedia;
-        if (m_mediaStatus != oldMediaStatus)
-            Q_EMIT mediaStatusChanged(m_mediaStatus);
     }
 
+    m_mediaStatus = QMediaPlayer::LoadingMedia;
+    if (m_mediaStatus != oldMediaStatus)
+        Q_EMIT mediaStatusChanged(m_mediaStatus);
+
     //Load AVURLAsset
     //initialize asset using content's URL
     NSString *urlString = [NSString stringWithUTF8String:content.canonicalUrl().toEncoded().constData()];
     NSURL *url = [NSURL URLWithString:urlString];
     [(AVFMediaPlayerSessionObserver*)m_observer setURL:url];
+
+    m_state = QMediaPlayer::StoppedState;
+    if (m_state != oldState)
+        Q_EMIT stateChanged(m_state);
 }
 
 qint64 AVFMediaPlayerSession::position() const
@@ -518,13 +531,7 @@ qint64 AVFMediaPlayerSession::duration() const
 #ifdef QT_DEBUG_AVF
     qDebug() << Q_FUNC_INFO;
 #endif
-    AVPlayerItem *playerItem = [(AVFMediaPlayerSessionObserver*)m_observer playerItem];
-
-    if (!playerItem)
-        return 0;
-
-    CMTime time = [playerItem duration];
-    return static_cast<quint64>(float(time.value) / float(time.timescale) * 1000.0f);
+    return m_duration;
 }
 
 int AVFMediaPlayerSession::bufferStatus() const
@@ -644,7 +651,9 @@ void AVFMediaPlayerSession::setPosition(qint64 pos)
         m_requestedPosition = pos;
         Q_EMIT positionChanged(m_requestedPosition);
         return;
-    } else if (!isSeekable()) {
+    }
+
+    if (!isSeekable()) {
         if (m_requestedPosition != -1) {
             m_requestedPosition = -1;
             Q_EMIT positionChanged(position());
@@ -660,9 +669,14 @@ void AVFMediaPlayerSession::setPosition(qint64 pos)
     newTime.value = (pos / 1000.0f) * newTime.timescale;
     [playerItem seekToTime:newTime];
 
-    //reset the EndOfMedia status position is changed after playback is finished
-    if (m_mediaStatus == QMediaPlayer::EndOfMedia)
-        processLoadStateChange();
+    Q_EMIT positionChanged(pos);
+
+    // Reset media status if the current status is EndOfMedia
+    if (m_mediaStatus == QMediaPlayer::EndOfMedia) {
+        QMediaPlayer::MediaStatus newMediaStatus = (m_state == QMediaPlayer::PausedState) ? QMediaPlayer::BufferedMedia
+                                                                                          : QMediaPlayer::LoadedMedia;
+        Q_EMIT mediaStatusChanged((m_mediaStatus = newMediaStatus));
+    }
 }
 
 void AVFMediaPlayerSession::play()
@@ -671,27 +685,28 @@ void AVFMediaPlayerSession::play()
     qDebug() << Q_FUNC_INFO << "currently: " << m_state;
 #endif
 
-    if (m_state == QMediaPlayer::PlayingState)
+    if (m_mediaStatus == QMediaPlayer::NoMedia || m_mediaStatus == QMediaPlayer::InvalidMedia)
         return;
 
-    m_state = QMediaPlayer::PlayingState;
+    if (m_state == QMediaPlayer::PlayingState)
+        return;
 
     if (m_videoOutput) {
         m_videoOutput->setLayer([(AVFMediaPlayerSessionObserver*)m_observer playerLayer]);
     }
 
-    //reset the EndOfMedia status if the same file is played again
-    if (m_mediaStatus == QMediaPlayer::EndOfMedia) {
+    // Reset media status if the current status is EndOfMedia
+    if (m_mediaStatus == QMediaPlayer::EndOfMedia)
         setPosition(0);
-        processLoadStateChange();
-    }
 
     if (m_mediaStatus == QMediaPlayer::LoadedMedia || m_mediaStatus == QMediaPlayer::BufferedMedia) {
         // Setting the rate starts playback
         [[(AVFMediaPlayerSessionObserver*)m_observer player] setRate:m_rate];
     }
 
-    //processLoadStateChange();
+    m_state = QMediaPlayer::PlayingState;
+    processLoadStateChange();
+
     Q_EMIT stateChanged(m_state);
 }
 
@@ -701,6 +716,9 @@ void AVFMediaPlayerSession::pause()
     qDebug() << Q_FUNC_INFO << "currently: " << m_state;
 #endif
 
+    if (m_mediaStatus == QMediaPlayer::NoMedia)
+        return;
+
     if (m_state == QMediaPlayer::PausedState)
         return;
 
@@ -710,13 +728,13 @@ void AVFMediaPlayerSession::pause()
         m_videoOutput->setLayer([(AVFMediaPlayerSessionObserver*)m_observer playerLayer]);
     }
 
-    //reset the EndOfMedia status if the same file is played again
-    if (m_mediaStatus == QMediaPlayer::EndOfMedia)
-        processLoadStateChange();
-
     [[(AVFMediaPlayerSessionObserver*)m_observer player] pause];
 
-    //processLoadStateChange();
+    // Reset media status if the current status is EndOfMedia
+    if (m_mediaStatus == QMediaPlayer::EndOfMedia)
+        setPosition(0);
+
+
     Q_EMIT stateChanged(m_state);
 }
 
@@ -729,7 +747,6 @@ void AVFMediaPlayerSession::stop()
     if (m_state == QMediaPlayer::StoppedState)
         return;
 
-    m_state = QMediaPlayer::StoppedState;
     // AVPlayer doesn't have stop(), only pause() and play().
     [[(AVFMediaPlayerSessionObserver*)m_observer player] pause];
     setPosition(0);
@@ -738,9 +755,11 @@ void AVFMediaPlayerSession::stop()
         m_videoOutput->setLayer(0);
     }
 
-    processLoadStateChange();
-    Q_EMIT stateChanged(m_state);
+    if (m_mediaStatus == QMediaPlayer::BufferedMedia)
+        Q_EMIT mediaStatusChanged((m_mediaStatus = QMediaPlayer::LoadedMedia));
+
     Q_EMIT positionChanged(position());
+    Q_EMIT stateChanged((m_state = QMediaPlayer::StoppedState));
 }
 
 void AVFMediaPlayerSession::setVolume(int volume)
@@ -749,11 +768,6 @@ void AVFMediaPlayerSession::setVolume(int volume)
     qDebug() << Q_FUNC_INFO << volume;
 #endif
 
-    if (!m_volumeSupported) {
-        qWarning("%s not implemented, requires iOS 7 or later", Q_FUNC_INFO);
-        return;
-    }
-
     if (m_volume == volume)
         return;
 
@@ -772,11 +786,6 @@ void AVFMediaPlayerSession::setMuted(bool muted)
     qDebug() << Q_FUNC_INFO << muted;
 #endif
 
-    if (!m_volumeSupported) {
-        qWarning("%s not implemented, requires iOS 7 or later", Q_FUNC_INFO);
-        return;
-    }
-
     if (m_muted == muted)
         return;
 
@@ -797,6 +806,8 @@ void AVFMediaPlayerSession::processEOS()
 #endif
     Q_EMIT positionChanged(position());
     m_mediaStatus = QMediaPlayer::EndOfMedia;
+    Q_EMIT mediaStatusChanged(m_mediaStatus);
+
     m_state = QMediaPlayer::StoppedState;
 
     // At this point, frames should not be rendered anymore.
@@ -804,23 +815,26 @@ void AVFMediaPlayerSession::processEOS()
     if (m_videoOutput)
         m_videoOutput->setLayer(0);
 
-    Q_EMIT mediaStatusChanged(m_mediaStatus);
     Q_EMIT stateChanged(m_state);
 }
 
-void AVFMediaPlayerSession::processLoadStateChange()
+void AVFMediaPlayerSession::processLoadStateChange(QMediaPlayer::State newState)
 {
     AVPlayerStatus currentStatus = [[(AVFMediaPlayerSessionObserver*)m_observer player] status];
 
 #ifdef QT_DEBUG_AVF
-    qDebug() << Q_FUNC_INFO << currentStatus;
+    qDebug() << Q_FUNC_INFO << currentStatus << ", " << m_mediaStatus << ", " << newState;
 #endif
 
-    QMediaPlayer::MediaStatus newStatus = QMediaPlayer::NoMedia;
-    bool isPlaying = (m_state != QMediaPlayer::StoppedState);
+    if (m_mediaStatus == QMediaPlayer::NoMedia)
+        return;
 
     if (currentStatus == AVPlayerStatusReadyToPlay) {
+
+        QMediaPlayer::MediaStatus newStatus = m_mediaStatus;
+
         AVPlayerItem *playerItem = [(AVFMediaPlayerSessionObserver*)m_observer playerItem];
+
         if (playerItem) {
             // Check each track for audio and video content
             AVAssetTrack *videoTrack = nil;
@@ -847,35 +861,57 @@ void AVFMediaPlayerSession::processLoadStateChange()
                                                 videoTrack.naturalSize.width,
                                                 videoTrack.naturalSize.height);
 
-                if (m_videoOutput && m_state != QMediaPlayer::StoppedState) {
+                if (m_videoOutput && newState != QMediaPlayer::StoppedState) {
                     m_videoOutput->setLayer(playerLayer);
                 }
             }
+
+            if (m_requestedPosition != -1) {
+                setPosition(m_requestedPosition);
+                m_requestedPosition = -1;
+            }
         }
 
-        qint64 currentDuration = duration();
-        if (m_duration != currentDuration)
-            Q_EMIT durationChanged(m_duration = currentDuration);
+        newStatus = (newState != QMediaPlayer::StoppedState) ? QMediaPlayer::BufferedMedia
+                                                             : QMediaPlayer::LoadedMedia;
 
-        if (m_requestedPosition != -1) {
-            setPosition(m_requestedPosition);
-            m_requestedPosition = -1;
-        }
+        if (newStatus != m_mediaStatus)
+            Q_EMIT mediaStatusChanged((m_mediaStatus = newStatus));
 
-        newStatus = isPlaying ? QMediaPlayer::BufferedMedia : QMediaPlayer::LoadedMedia;
-
-        if (m_state == QMediaPlayer::PlayingState && [(AVFMediaPlayerSessionObserver*)m_observer player]) {
-            // Setting the rate is enough to start playback, no need to call play()
-            [[(AVFMediaPlayerSessionObserver*)m_observer player] setRate:m_rate];
-        }
     }
 
-    if (newStatus != m_mediaStatus)
-        Q_EMIT mediaStatusChanged(m_mediaStatus = newStatus);
+    if (newState == QMediaPlayer::PlayingState && [(AVFMediaPlayerSessionObserver*)m_observer player]) {
+        // Setting the rate is enough to start playback, no need to call play()
+        [[(AVFMediaPlayerSessionObserver*)m_observer player] setRate:m_rate];
+    }
+}
+
+
+void AVFMediaPlayerSession::processLoadStateChange()
+{
+    processLoadStateChange(m_state);
+}
+
+
+void AVFMediaPlayerSession::processLoadStateFailure()
+{
+    Q_EMIT stateChanged((m_state = QMediaPlayer::StoppedState));
+}
+
+void AVFMediaPlayerSession::processDurationChange(qint64 duration)
+{
+    if (duration == m_duration)
+        return;
+
+    m_duration = duration;
+    Q_EMIT durationChanged(duration);
 }
 
 void AVFMediaPlayerSession::processPositionChange()
 {
+    if (m_state == QMediaPlayer::StoppedState)
+        return;
+
     Q_EMIT positionChanged(position());
 }
 
@@ -886,10 +922,7 @@ void AVFMediaPlayerSession::processMediaLoadError()
         Q_EMIT positionChanged(position());
     }
 
-    m_mediaStatus = QMediaPlayer::InvalidMedia;
-    m_state = QMediaPlayer::StoppedState;
+    Q_EMIT mediaStatusChanged((m_mediaStatus = QMediaPlayer::InvalidMedia));
 
     Q_EMIT error(QMediaPlayer::FormatError, tr("Failed to load media"));
-    Q_EMIT mediaStatusChanged(m_mediaStatus);
-    Q_EMIT stateChanged(m_state);
 }
