@@ -42,10 +42,6 @@
 #import <AVFoundation/AVAudioSession.h>
 #import <Foundation/Foundation.h>
 
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-#include <AudioToolbox/AudioToolbox.h>
-#endif
-
 QT_BEGIN_NAMESPACE
 
 @interface CoreAudioSessionObserver : NSObject
@@ -81,24 +77,19 @@ QT_BEGIN_NAMESPACE
         self->m_sessionManager = sessionManager;
         self->m_audioSession = [AVAudioSession sharedInstance];
 
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-        if (QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0)
-#endif
-        {
-            //Set up observers
-            [[NSNotificationCenter defaultCenter] addObserver:self
-                                                     selector:@selector(audioSessionInterruption:)
-                                                         name:AVAudioSessionInterruptionNotification
-                                                       object:self->m_audioSession];
-            [[NSNotificationCenter defaultCenter] addObserver:self
-                                                     selector:@selector(audioSessionMediaServicesWereReset:)
-                                                         name:AVAudioSessionMediaServicesWereResetNotification
-                                                       object:self->m_audioSession];
-            [[NSNotificationCenter defaultCenter] addObserver:self
-                                                     selector:@selector(audioSessionRouteChange:)
-                                                         name:AVAudioSessionRouteChangeNotification
-                                                       object:self->m_audioSession];
-        }
+        //Set up observers
+        [[NSNotificationCenter defaultCenter] addObserver:self
+                                                 selector:@selector(audioSessionInterruption:)
+                                                     name:AVAudioSessionInterruptionNotification
+                                                   object:self->m_audioSession];
+        [[NSNotificationCenter defaultCenter] addObserver:self
+                                                 selector:@selector(audioSessionMediaServicesWereReset:)
+                                                     name:AVAudioSessionMediaServicesWereResetNotification
+                                                   object:self->m_audioSession];
+        [[NSNotificationCenter defaultCenter] addObserver:self
+                                                 selector:@selector(audioSessionRouteChange:)
+                                                     name:AVAudioSessionRouteChangeNotification
+                                                   object:self->m_audioSession];
 
         return self;
 }
@@ -109,20 +100,15 @@ QT_BEGIN_NAMESPACE
     qDebug() << Q_FUNC_INFO;
 #endif
 
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-    if (QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0)
-#endif
-    {
-        [[NSNotificationCenter defaultCenter] removeObserver:self
-                                                        name:AVAudioSessionInterruptionNotification
-                                                      object:self->m_audioSession];
-        [[NSNotificationCenter defaultCenter] removeObserver:self
-                                                        name:AVAudioSessionMediaServicesWereResetNotification
-                                                      object:self->m_audioSession];
-        [[NSNotificationCenter defaultCenter] removeObserver:self
-                                                        name:AVAudioSessionRouteChangeNotification
-                                                      object:self->m_audioSession];
-    }
+    [[NSNotificationCenter defaultCenter] removeObserver:self
+                                                    name:AVAudioSessionInterruptionNotification
+                                                  object:self->m_audioSession];
+    [[NSNotificationCenter defaultCenter] removeObserver:self
+                                                    name:AVAudioSessionMediaServicesWereResetNotification
+                                                  object:self->m_audioSession];
+    [[NSNotificationCenter defaultCenter] removeObserver:self
+                                                    name:AVAudioSessionRouteChangeNotification
+                                                  object:self->m_audioSession];
 
     [super dealloc];
 }
@@ -285,9 +271,6 @@ bool CoreAudioSessionManager::setCategory(CoreAudioSessionManager::AudioSessionC
 #endif
         break;
     case CoreAudioSessionManager::MultiRoute:
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-        if (QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0)
-#endif
         targetCategory = AVAudioSessionCategoryMultiRoute;
         break;
     }
@@ -295,16 +278,9 @@ bool CoreAudioSessionManager::setCategory(CoreAudioSessionManager::AudioSessionC
     if (targetCategory == nil)
         return false;
 
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-    if (QSysInfo::MacintoshVersion < QSysInfo::MV_IOS_6_0) {
-        return [[m_sessionObserver audioSession] setCategory:targetCategory error:nil];
-    } else
-#endif
-    {
-        return [[m_sessionObserver audioSession] setCategory:targetCategory
-                                                 withOptions:(AVAudioSessionCategoryOptions)options
-                                                       error:nil];
-    }
+    return [[m_sessionObserver audioSession] setCategory:targetCategory
+                                             withOptions:(AVAudioSessionCategoryOptions)options
+                                                   error:nil];
 }
 
 bool CoreAudioSessionManager::setMode(CoreAudioSessionManager::AudioSessionModes mode)
@@ -327,9 +303,6 @@ bool CoreAudioSessionManager::setMode(CoreAudioSessionManager::AudioSessionModes
         targetMode = AVAudioSessionModeMeasurement;
         break;
     case CoreAudioSessionManager::MoviePlayback:
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-        if (QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0)
-#endif
         targetMode = AVAudioSessionModeMoviePlayback;
         break;
     }
@@ -360,11 +333,7 @@ CoreAudioSessionManager::AudioSessionCategorys CoreAudioSessionManager::category
     } else if (category == AVAudioSessionCategoryAudioProcessing) {
         localCategory = AudioProcessing;
 #endif
-    } else if (
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-               QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0 &&
-#endif
-               category == AVAudioSessionCategoryMultiRoute) {
+    } else if (category == AVAudioSessionCategoryMultiRoute) {
         localCategory = MultiRoute;
     }
 
@@ -386,11 +355,7 @@ CoreAudioSessionManager::AudioSessionModes CoreAudioSessionManager::mode()
         localMode = VideoRecording;
     } else if (mode == AVAudioSessionModeMeasurement) {
         localMode = Measurement;
-    } else if (
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-               QSysInfo::MacintoshVersion >= QSysInfo::MV_IOS_6_0 &&
-#endif
-               mode == AVAudioSessionModeMoviePlayback) {
+    } else if (mode == AVAudioSessionModeMoviePlayback) {
         localMode = MoviePlayback;
     }
 
@@ -419,32 +384,12 @@ QList<QByteArray> CoreAudioSessionManager::outputDevices()
 
 float CoreAudioSessionManager::currentIOBufferDuration()
 {
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-    if (QSysInfo::MacintoshVersion < QSysInfo::MV_IOS_6_0) {
-        Float32 duration;
-        UInt32 size = sizeof(duration);
-        AudioSessionGetProperty(kAudioSessionProperty_CurrentHardwareIOBufferDuration, &size, &duration);
-        return duration;
-    } else
-#endif
-    {
-        return [[m_sessionObserver audioSession] IOBufferDuration];
-    }
+    return [[m_sessionObserver audioSession] IOBufferDuration];
 }
 
 float CoreAudioSessionManager::preferredSampleRate()
 {
-#if QT_IOS_DEPLOYMENT_TARGET_BELOW(__IPHONE_6_0)
-    if (QSysInfo::MacintoshVersion < QSysInfo::MV_IOS_6_0) {
-        Float64 sampleRate;
-        UInt32 size = sizeof(sampleRate);
-        AudioSessionGetProperty(kAudioSessionProperty_PreferredHardwareSampleRate, &size, &sampleRate);
-        return sampleRate;
-    } else
-#endif
-    {
-        return [[m_sessionObserver audioSession] preferredSampleRate];
-    }
+    return [[m_sessionObserver audioSession] preferredSampleRate];
 }
 
 #ifdef QT_DEBUG_COREAUDIO
