@@ -56,6 +56,7 @@
 #include <dshow.h>
 #include <objbase.h>
 #include <initguid.h>
+#include "directshowmediatype.h"
 #ifdef Q_CC_MSVC
 #  pragma comment(lib, "strmiids.lib")
 #  pragma comment(lib, "ole32.lib")
@@ -71,11 +72,10 @@
 #define __IDxtKey_INTERFACE_DEFINED__
 
 struct ICaptureGraphBuilder2;
-struct ISampleGrabber;
 
 QT_BEGIN_NAMESPACE
 
-class SampleGrabberCallbackPrivate;
+class DirectShowSampleGrabber;
 
 class DSCameraSession : public QObject
 {
@@ -118,6 +118,8 @@ public:
             QCameraImageProcessingControl::ProcessingParameter,
             const QVariant &);
 
+    bool getCameraControlInterface(IAMCameraControl **cameraControl) const;
+
 Q_SIGNALS:
     void statusChanged(QCamera::Status);
     void imageExposed(int id);
@@ -154,7 +156,7 @@ private:
 
     void setStatus(QCamera::Status status);
 
-    void onFrameAvailable(const char *frameData, long len);
+    void onFrameAvailable(double time, const QByteArray &data);
     void saveCapturedImage(int id, const QImage &image, const QString &path);
 
     bool createFilterGraph();
@@ -182,14 +184,13 @@ private:
     QString m_sourceDeviceName;
     IBaseFilter* m_sourceFilter;
     bool m_needsHorizontalMirroring;
-    QList<AM_MEDIA_TYPE> m_supportedFormats;
+    QList<DirectShowMediaType> m_supportedFormats;
     QList<QCameraViewfinderSettings> m_supportedViewfinderSettings;
-    AM_MEDIA_TYPE m_sourceFormat;
+    DirectShowMediaType m_sourceFormat;
     QMap<QCameraImageProcessingControl::ProcessingParameter, ImageProcessingParameterInfo> m_imageProcessingParametersInfos;
 
     // Preview
-    IBaseFilter *m_previewFilter;
-    ISampleGrabber *m_previewSampleGrabber;
+    DirectShowSampleGrabber *m_previewSampleGrabber;
     IBaseFilter *m_nullRendererFilter;
     QVideoFrame m_currentFrame;
     bool m_previewStarted;
