@@ -41,11 +41,14 @@
 
 #include "directshowglobal.h"
 #include "directshowmediatype.h"
+#include "directshowmediatypeenum.h"
 #include "directshowpinenum.h"
 
 #include <QtCore/qcoreapplication.h>
 #include <QtCore/qurl.h>
 
+QT_BEGIN_NAMESPACE
+
 static const GUID directshow_subtypes[] =
 {
     MEDIASUBTYPE_NULL,
@@ -81,8 +84,7 @@ DirectShowIOSource::DirectShowIOSource(DirectShowEventLoop *loop)
     // The filter works in pull mode, the downstream filter is responsible for requesting
     // samples from this one.
     //
-    QVector<AM_MEDIA_TYPE> mediaTypes;
-    AM_MEDIA_TYPE type =
+    AM_MEDIA_TYPE type
     {
         MEDIATYPE_Stream,  // majortype
         MEDIASUBTYPE_NULL, // subtype
@@ -99,10 +101,8 @@ DirectShowIOSource::DirectShowIOSource(DirectShowEventLoop *loop)
 
     for (int i = 0; i < count; ++i) {
         type.subtype = directshow_subtypes[i];
-        mediaTypes.append(type);
+        m_supportedMediaTypes.append(DirectShowMediaType(type));
     }
-
-    setMediaTypes(mediaTypes);
 }
 
 DirectShowIOSource::~DirectShowIOSource()
@@ -373,28 +373,24 @@ HRESULT DirectShowIOSource::Connect(IPin *pReceivePin, const AM_MEDIA_TYPE *pmt)
          hr = pReceivePin->ReceiveConnection(this, pmt);
          // Update the media type for the current connection.
          if (SUCCEEDED(hr))
-             m_connectionMediaType = *pmt;
+             DirectShowMediaType::copy(&m_connectionMediaType, pmt);
     } else if (pmt && pmt->subtype == MEDIATYPE_NULL) { // - Partial type (Stream, but no subtype specified).
-        m_connectionMediaType = *pmt;
+        DirectShowMediaType::copy(&m_connectionMediaType, pmt);
         // Check if the receiving pin accepts any of the streaming subtypes.
-        QVector<AM_MEDIA_TYPE>::const_iterator cit = m_mediaTypes.constBegin();
-        while (cit != m_mediaTypes.constEnd()) {
-            m_connectionMediaType.subtype = cit->subtype;
+        for (const DirectShowMediaType &t : qAsConst(m_supportedMediaTypes)) {
+            m_connectionMediaType->subtype = t->subtype;
             hr = pReceivePin->ReceiveConnection(this, &m_connectionMediaType);
             if (SUCCEEDED(hr))
                 break;
-            ++cit;
         }
     } else { // - No media type specified.
         // Check if the receiving pin accepts any of the streaming types.
-        QVector<AM_MEDIA_TYPE>::const_iterator cit = m_mediaTypes.constBegin();
-        while (cit != m_mediaTypes.constEnd()) {
-            hr = pReceivePin->ReceiveConnection(this, cit);
+        for (const DirectShowMediaType &t : qAsConst(m_supportedMediaTypes)) {
+            hr = pReceivePin->ReceiveConnection(this, &t);
             if (SUCCEEDED(hr)) {
-                m_connectionMediaType = *cit;
+                m_connectionMediaType = t;
                 break;
             }
-            ++cit;
         }
     }
 
@@ -483,7 +479,7 @@ HRESULT DirectShowIOSource::ConnectionMediaType(AM_MEDIA_TYPE *pmt)
 
             return VFW_E_NOT_CONNECTED;
         } else {
-            DirectShowMediaType::copy(pmt, m_connectionMediaType);
+            DirectShowMediaType::copy(pmt, &m_connectionMediaType);
 
             return S_OK;
         }
@@ -539,7 +535,7 @@ HRESULT DirectShowIOSource::EnumMediaTypes(IEnumMediaTypes **ppEnum)
     if (!ppEnum) {
         return E_POINTER;
     } else {
-        *ppEnum = createMediaTypeEnum();
+        *ppEnum = new DirectShowMediaTypeEnum(m_supportedMediaTypes);
 
         return S_OK;
     }
@@ -587,3 +583,5 @@ HRESULT DirectShowIOSource::QueryDirection(PIN_DIRECTION *pPinDir)
         return S_OK;
     }
 }
+
+QT_END_NAMESPACE
