@@ -46,6 +46,8 @@
 
 #include <QtCore/qfile.h>
 
+QT_BEGIN_NAMESPACE
+
 class DirectShowIOSource
     : public IBaseFilter
     , public IAMFilterMiscFlags
@@ -131,4 +133,6 @@ private:
     QMutex m_mutex;
 };
 
+QT_END_NAMESPACE
+
 #endif
