@@ -37,8 +37,8 @@
 **
 ****************************************************************************/
 
-#ifndef CAMERABINEXPOSURECONTROL_MAEMO_H
-#define CAMERABINEXPOSURECONTROL_MAEMO_H
+#ifndef CAMERABINEXPOSURECONTROL_H
+#define CAMERABINEXPOSURECONTROL_H
 
 #include <qcamera.h>
 #include <qcameraexposurecontrol.h>
@@ -58,12 +58,12 @@ public:
     CameraBinExposure(CameraBinSession *session);
     virtual ~CameraBinExposure();
 
-    bool isParameterSupported(ExposureParameter parameter) const;
-    QVariantList supportedParameterRange(ExposureParameter parameter, bool *continuous) const;
+    bool isParameterSupported(ExposureParameter parameter) const override;
+    QVariantList supportedParameterRange(ExposureParameter parameter, bool *continuous) const override;
 
-    QVariant requestedValue(ExposureParameter parameter) const;
-    QVariant actualValue(ExposureParameter parameter) const;
-    bool setValue(ExposureParameter parameter, const QVariant& value);
+    QVariant requestedValue(ExposureParameter parameter) const override;
+    QVariant actualValue(ExposureParameter parameter) const override;
+    bool setValue(ExposureParameter parameter, const QVariant &value) override;
 
 private:
     CameraBinSession *m_session;
@@ -72,4 +72,4 @@ private:
 
 QT_END_NAMESPACE
 
-#endif // CAMERABINEXPOSURECONTROL_MAEMO_H
+#endif // CAMERABINEXPOSURECONTROL_H
