@@ -119,6 +119,9 @@ QMediaPlayerResourceSetInterface* QGstreamerPlayerControl::resources() const
 
 qint64 QGstreamerPlayerControl::position() const
 {
+    if (m_mediaStatus == QMediaPlayer::EndOfMedia)
+        return m_session->duration();
+
     return m_pendingSeekPosition != -1 ? m_pendingSeekPosition : m_session->position();
 }
 
@@ -379,7 +382,7 @@ void QGstreamerPlayerControl::setMedia(const QMediaContent &content, QIODevice *
         request = content.canonicalRequest();
     }
 
-#if !defined(HAVE_GST_APPSRC)
+#if !QT_CONFIG(gstreamer_app)
     m_session->loadFromUri(request);
 #else
     if (m_stream) {
@@ -397,7 +400,7 @@ void QGstreamerPlayerControl::setMedia(const QMediaContent &content, QIODevice *
         m_session->loadFromUri(request);
 #endif
 
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
     if (!request.url().isEmpty() || userStreamValid) {
 #else
     if (!request.url().isEmpty()) {
