@@ -47,7 +47,6 @@
 #include <private/gstvideoconnector_p.h>
 #endif
 #include <private/qgstutils_p.h>
-#include <private/playlistfileparser_p.h>
 #include <private/qgstutils_p.h>
 
 #include <gst/gstvalue.h>
@@ -127,7 +126,7 @@ QGstreamerPlayerSession::QGstreamerPlayerSession(QObject *parent)
      m_bus(0),
      m_videoOutput(0),
      m_renderer(0),
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
      m_appSrc(0),
 #endif
      m_videoProbe(0),
@@ -144,21 +143,12 @@ QGstreamerPlayerSession::QGstreamerPlayerSession(QObject *parent)
      m_displayPrerolledFrame(true),
      m_sourceType(UnknownSrc),
      m_everPlayed(false),
-     m_isLiveSource(false),
-     m_isPlaylist(false)
+     m_isLiveSource(false)
 {
-    gboolean result = gst_type_find_register(0, "playlist", GST_RANK_MARGINAL, playlistTypeFindFunction, 0, 0, this, 0);
-    Q_ASSERT(result == TRUE);
-    Q_UNUSED(result);
-
     m_playbin = gst_element_factory_make(QT_GSTREAMER_PLAYBIN_ELEMENT_NAME, NULL);
     if (m_playbin) {
         //GST_PLAY_FLAG_NATIVE_VIDEO omits configuration of ffmpegcolorspace and videoscale,
         //since those elements are included in the video output bin when necessary.
-#ifdef Q_WS_MAEMO_6
-        int flags = GST_PLAY_FLAG_VIDEO | GST_PLAY_FLAG_AUDIO |
-                    GST_PLAY_FLAG_NATIVE_VIDEO | GST_PLAY_FLAG_NATIVE_AUDIO;
-#else
         int flags = GST_PLAY_FLAG_VIDEO | GST_PLAY_FLAG_AUDIO;
         QByteArray envFlags = qgetenv("QT_GSTREAMER_PLAYBIN_FLAGS");
         if (!envFlags.isEmpty()) {
@@ -168,10 +158,10 @@ QGstreamerPlayerSession::QGstreamerPlayerSession(QObject *parent)
             flags |= GST_PLAY_FLAG_NATIVE_VIDEO;
 #endif
         }
-#endif
         g_object_set(G_OBJECT(m_playbin), "flags", flags, NULL);
 
-        GstElement *audioSink = gst_element_factory_make("autoaudiosink", "audiosink");
+        const QByteArray envAudioSink = qgetenv("QT_GSTREAMER_PLAYBIN_AUDIOSINK");
+        GstElement *audioSink = gst_element_factory_make(envAudioSink.isEmpty() ? "autoaudiosink" : envAudioSink, "audiosink");
         if (audioSink) {
             if (usePlaybinVolume()) {
                 m_audioSink = audioSink;
@@ -248,7 +238,7 @@ QGstreamerPlayerSession::QGstreamerPlayerSession(QObject *parent)
         g_signal_connect(G_OBJECT(m_playbin), "audio-changed", G_CALLBACK(handleStreamsChange), this);
         g_signal_connect(G_OBJECT(m_playbin), "text-changed", G_CALLBACK(handleStreamsChange), this);
 
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
         g_signal_connect(G_OBJECT(m_playbin), "deep-notify::source", G_CALLBACK(configureAppSrcElement), this);
 #endif
     }
@@ -278,7 +268,7 @@ GstElement *QGstreamerPlayerSession::playbin() const
     return m_playbin;
 }
 
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
 void QGstreamerPlayerSession::configureAppSrcElement(GObject* object, GObject *orig, GParamSpec *pspec, QGstreamerPlayerSession* self)
 {
     Q_UNUSED(object);
@@ -299,14 +289,13 @@ void QGstreamerPlayerSession::configureAppSrcElement(GObject* object, GObject *o
 
 void QGstreamerPlayerSession::loadFromStream(const QNetworkRequest &request, QIODevice *appSrcStream)
 {
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
 #ifdef DEBUG_PLAYBIN
     qDebug() << Q_FUNC_INFO;
 #endif
     m_request = request;
     m_duration = -1;
     m_lastPosition = 0;
-    m_isPlaylist = false;
 
     if (!m_appSrc)
         m_appSrc = new QGstAppSrc(this);
@@ -336,9 +325,8 @@ void QGstreamerPlayerSession::loadFromUri(const QNetworkRequest &request)
     m_request = request;
     m_duration = -1;
     m_lastPosition = 0;
-    m_isPlaylist = false;
 
-#if defined(HAVE_GST_APPSRC)
+#if QT_CONFIG(gstreamer_app)
     if (m_appSrc) {
         m_appSrc->deleteLater();
         m_appSrc = 0;
@@ -904,13 +892,9 @@ bool QGstreamerPlayerSession::play()
     if (m_playbin) {
         m_pendingState = QMediaPlayer::PlayingState;
         if (gst_element_set_state(m_playbin, GST_STATE_PLAYING) == GST_STATE_CHANGE_FAILURE) {
-            if (!m_isPlaylist) {
-                qWarning() << "GStreamer; Unable to play -" << m_request.url().toString();
-                m_pendingState = m_state = QMediaPlayer::StoppedState;
-                emit stateChanged(m_state);
-            } else {
-                return true;
-            }
+            qWarning() << "GStreamer; Unable to play -" << m_request.url().toString();
+            m_pendingState = m_state = QMediaPlayer::StoppedState;
+            emit stateChanged(m_state);
         } else {
             resumeVideoProbes();
             return true;
@@ -931,13 +915,9 @@ bool QGstreamerPlayerSession::pause()
             return true;
 
         if (gst_element_set_state(m_playbin, GST_STATE_PAUSED) == GST_STATE_CHANGE_FAILURE) {
-            if (!m_isPlaylist) {
-                qWarning() << "GStreamer; Unable to pause -" << m_request.url().toString();
-                m_pendingState = m_state = QMediaPlayer::StoppedState;
-                emit stateChanged(m_state);
-            } else {
-                return true;
-            }
+            qWarning() << "GStreamer; Unable to pause -" << m_request.url().toString();
+            m_pendingState = m_state = QMediaPlayer::StoppedState;
+            emit stateChanged(m_state);
         } else {
             resumeVideoProbes();
             return true;
@@ -1306,7 +1286,7 @@ bool QGstreamerPlayerSession::processBusMessage(const QGstreamerMessage &message
                 if (err->domain == GST_STREAM_ERROR && err->code == GST_STREAM_ERROR_CODEC_NOT_FOUND)
                     emit error(int(QMediaPlayer::FormatError), tr("Cannot play stream of type: <unknown>"));
                 // GStreamer shows warning for HTTP playlists
-                if (!m_isPlaylist)
+                if (err && err->message)
                     qWarning() << "Warning:" << QString::fromUtf8(err->message);
                 g_error_free(err);
                 g_free(debug);
@@ -1315,10 +1295,6 @@ bool QGstreamerPlayerSession::processBusMessage(const QGstreamerMessage &message
                 gchar *debug;
                 gst_message_parse_error(gm, &err, &debug);
 
-                // remember playlist value,
-                // it could be set to false after call to processInvalidMedia
-                bool isPlaylist = m_isPlaylist;
-
                 // Nearly all errors map to ResourceError
                 QMediaPlayer::Error qerror = QMediaPlayer::ResourceError;
                 if (err->domain == GST_STREAM_ERROR
@@ -1327,7 +1303,7 @@ bool QGstreamerPlayerSession::processBusMessage(const QGstreamerMessage &message
                     qerror = QMediaPlayer::AccessDeniedError;
                 }
                 processInvalidMedia(qerror, QString::fromUtf8(err->message));
-                if (!isPlaylist)
+                if (err && err->message)
                     qWarning() << "Error:" << QString::fromUtf8(err->message);
 
                 g_error_free(err);
@@ -1565,10 +1541,17 @@ void QGstreamerPlayerSession::playbinNotifySource(GObject *o, GParamSpec *p, gpo
     //set timeout property to 30 seconds
     const int timeout = 30;
     if (qstrcmp(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(source)), "GstUDPSrc") == 0) {
-        //udpsrc timeout unit = microsecond
-        //The udpsrc is always a live source.
-        g_object_set(G_OBJECT(source), "timeout", G_GUINT64_CONSTANT(timeout*1000000), NULL);
+        quint64 convertedTimeout = timeout;
+#if GST_CHECK_VERSION(1,0,0)
+        // Gst 1.x -> nanosecond
+        convertedTimeout *= 1000000000;
+#else
+        // Gst 0.10 -> microsecond
+        convertedTimeout *= 1000000;
+#endif
+        g_object_set(G_OBJECT(source), "timeout", convertedTimeout, NULL);
         self->m_sourceType = UDPSrc;
+        //The udpsrc is always a live source.
         self->m_isLiveSource = true;
     } else if (qstrcmp(G_OBJECT_CLASS_NAME(G_OBJECT_GET_CLASS(source)), "GstSoupHTTPSrc") == 0) {
         //souphttpsrc timeout unit = second
@@ -1763,14 +1746,9 @@ void QGstreamerPlayerSession::processInvalidMedia(QMediaPlayer::Error errorCode,
 #ifdef DEBUG_PLAYBIN
     qDebug() << Q_FUNC_INFO;
 #endif
-    if (m_isPlaylist) {
-        stop();
-        emit error(int(QMediaPlayer::MediaIsPlaylist), tr("Media is loaded as a playlist"));
-    } else {
-        emit invalidMedia();
-        stop();
-        emit error(int(errorCode), errorString);
-    }
+    emit invalidMedia();
+    stop();
+    emit error(int(errorCode), errorString);
 }
 
 void QGstreamerPlayerSession::showPrerollFrames(bool enabled)
@@ -1895,32 +1873,4 @@ void QGstreamerPlayerSession::resumeVideoProbes()
         m_videoProbe->stopFlushing();
 }
 
-void QGstreamerPlayerSession::playlistTypeFindFunction(GstTypeFind *find, gpointer userData)
-{
-    QGstreamerPlayerSession* session = (QGstreamerPlayerSession*)userData;
-
-    const gchar *uri = 0;
-#if GST_CHECK_VERSION(1,0,0)
-    g_object_get(G_OBJECT(session->m_playbin), "current-uri", &uri, NULL);
-#else
-    g_object_get(G_OBJECT(session->m_playbin), "uri", &uri, NULL);
-#endif
-
-    guint64 length = gst_type_find_get_length(find);
-    if (!length)
-        length = 1024;
-    else
-        length = qMin(length, guint64(1024));
-
-    while (length > 0) {
-        const guint8 *data = gst_type_find_peek(find, 0, length);
-        if (data) {
-            session->m_isPlaylist = (QPlaylistFileParser::findPlaylistType(QString::fromUtf8(uri), 0, data, length) != QPlaylistFileParser::UNKNOWN);
-            return;
-        }
-        length >>= 1; // for HTTP files length is not available,
-                      // so we have to try different buffer sizes
-    }
-}
-
 QT_END_NAMESPACE
