@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
@@ -10,30 +10,28 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -42,6 +40,7 @@
 #include <QtCore/qcoreapplication.h>
 #include <QtCore/qdebug.h>
 #include <QtCore/qmath.h>
+#include <private/qaudiohelpers_p.h>
 
 #include "qaudioinput_pulse.h"
 #include "qaudiodeviceinfo_pulse.h"
@@ -54,10 +53,6 @@ QT_BEGIN_NAMESPACE
 
 const int PeriodTimeMs = 50;
 
-// Map from void* (for userdata) to QPulseAudioInput instance
-// protected by pulse mainloop lock
-QMap<void *, QPulseAudioInput*> QPulseAudioInput::s_inputsMap;
-
 static void inputStreamReadCallback(pa_stream *stream, size_t length, void *userdata)
 {
     Q_UNUSED(userdata);
@@ -130,33 +125,6 @@ static void inputStreamSuccessCallback(pa_stream *stream, int success, void *use
     pa_threaded_mainloop_signal(pulseEngine->mainloop(), 0);
 }
 
-void QPulseAudioInput::sourceInfoCallback(pa_context *context, const pa_source_info *i, int eol, void *userdata)
-{
-    Q_UNUSED(context);
-    Q_UNUSED(eol);
-
-    Q_ASSERT(userdata);
-    QPulseAudioInput *that = QPulseAudioInput::s_inputsMap.value(userdata);
-    if (that && i) {
-        that->m_volume = pa_sw_volume_to_linear(pa_cvolume_avg(&i->volume));
-    }
-}
-
-void QPulseAudioInput::inputVolumeCallback(pa_context *context, int success, void *userdata)
-{
-    Q_UNUSED(success);
-
-    if (!success)
-        qWarning() << "QAudioInput: failed to set input volume";
-
-    QPulseAudioInput *that = QPulseAudioInput::s_inputsMap.value(userdata);
-
-    // Regardless of success or failure, we update the volume property
-    if (that && that->m_stream) {
-        pa_context_get_source_info_by_index(context, pa_stream_get_device_index(that->m_stream), sourceInfoCallback, userdata);
-    }
-}
-
 QPulseAudioInput::QPulseAudioInput(const QByteArray &device)
     : m_totalTimeValue(0)
     , m_audioSource(0)
@@ -175,31 +143,39 @@ QPulseAudioInput::QPulseAudioInput(const QByteArray &device)
 {
     m_timer = new QTimer(this);
     connect(m_timer, SIGNAL(timeout()), SLOT(userFeed()));
-
-    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-    pa_threaded_mainloop_lock(pulseEngine->mainloop());
-    s_inputsMap.insert(this, this);
-    pa_threaded_mainloop_unlock(pulseEngine->mainloop());
 }
 
 QPulseAudioInput::~QPulseAudioInput()
 {
-    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-    pa_threaded_mainloop_lock(pulseEngine->mainloop());
-    s_inputsMap.remove(this);
-    pa_threaded_mainloop_unlock(pulseEngine->mainloop());
-
     close();
     disconnect(m_timer, SIGNAL(timeout()));
     QCoreApplication::processEvents();
     delete m_timer;
 }
 
+void QPulseAudioInput::setError(QAudio::Error error)
+{
+    if (m_errorState == error)
+        return;
+
+    m_errorState = error;
+    emit errorChanged(error);
+}
+
 QAudio::Error QPulseAudioInput::error() const
 {
     return m_errorState;
 }
 
+void QPulseAudioInput::setState(QAudio::State state)
+{
+    if (m_deviceState == state)
+        return;
+
+    m_deviceState = state;
+    emit stateChanged(state);
+}
+
 QAudio::State QPulseAudioInput::state() const
 {
     return m_deviceState;
@@ -218,41 +194,45 @@ QAudioFormat QPulseAudioInput::format() const
 
 void QPulseAudioInput::start(QIODevice *device)
 {
-    if (m_deviceState != QAudio::StoppedState)
-        close();
+    setState(QAudio::StoppedState);
+    setError(QAudio::NoError);
 
-    if (!m_pullMode && m_audioSource)
+    if (!m_pullMode && m_audioSource) {
         delete m_audioSource;
+        m_audioSource = 0;
+    }
 
-    m_pullMode = true;
-    m_audioSource = device;
-
-    m_deviceState = QAudio::ActiveState;
+    close();
 
     if (!open())
         return;
 
-    emit stateChanged(m_deviceState);
+    m_pullMode = true;
+    m_audioSource = device;
+
+    setState(QAudio::ActiveState);
 }
 
 QIODevice *QPulseAudioInput::start()
 {
-    if (m_deviceState != QAudio::StoppedState)
-        close();
+    setState(QAudio::StoppedState);
+    setError(QAudio::NoError);
 
-    if (!m_pullMode && m_audioSource)
+    if (!m_pullMode && m_audioSource) {
         delete m_audioSource;
+        m_audioSource = 0;
+    }
 
-    m_pullMode = false;
-    m_audioSource = new InputPrivate(this);
-    m_audioSource->open(QIODevice::ReadOnly | QIODevice::Unbuffered);
-
-    m_deviceState = QAudio::IdleState;
+    close();
 
     if (!open())
-        return 0;
+        return Q_NULLPTR;
 
-    emit stateChanged(m_deviceState);
+    m_pullMode = false;
+    m_audioSource = new PulseInputPrivate(this);
+    m_audioSource->open(QIODevice::ReadOnly | QIODevice::Unbuffered);
+
+    setState(QAudio::IdleState);
 
     return m_audioSource;
 }
@@ -262,40 +242,43 @@ void QPulseAudioInput::stop()
     if (m_deviceState == QAudio::StoppedState)
         return;
 
-    m_errorState = QAudio::NoError;
-    m_deviceState = QAudio::StoppedState;
-
     close();
-    emit stateChanged(m_deviceState);
+
+    setError(QAudio::NoError);
+    setState(QAudio::StoppedState);
 }
 
 bool QPulseAudioInput::open()
 {
     if (m_opened)
+        return true;
+
+    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
+
+    if (!pulseEngine->context() || pa_context_get_state(pulseEngine->context()) != PA_CONTEXT_READY) {
+        setError(QAudio::FatalError);
+        setState(QAudio::StoppedState);
         return false;
+    }
+
+    pa_sample_spec spec = QPulseAudioInternal::audioFormatToSampleSpec(m_format);
+
+    if (!pa_sample_spec_valid(&spec)) {
+        setError(QAudio::OpenError);
+        setState(QAudio::StoppedState);
+        return false;
+    }
+
+    m_spec = spec;
 
 #ifdef DEBUG_PULSE
 //    QTime now(QTime::currentTime());
 //    qDebug()<<now.second()<<"s "<<now.msec()<<"ms :open()";
 #endif
-    m_clockStamp.restart();
-    m_timeStamp.restart();
-    m_elapsedTimeOffset = 0;
 
     if (m_streamName.isNull())
         m_streamName = QString(QLatin1String("QtmPulseStream-%1-%2")).arg(::getpid()).arg(quintptr(this)).toUtf8();
 
-    pa_sample_spec spec = QPulseAudioInternal::audioFormatToSampleSpec(m_format);
-
-    if (!pa_sample_spec_valid(&spec)) {
-        m_errorState = QAudio::OpenError;
-        m_deviceState = QAudio::StoppedState;
-        emit stateChanged(m_deviceState);
-        return false;
-    }
-
-    m_spec = spec;
-
 #ifdef DEBUG_PULSE
         qDebug() << "Format: " << QPulseAudioInternal::sampleFormatToQString(spec.format);
         qDebug() << "Rate: " << spec.rate;
@@ -303,15 +286,13 @@ bool QPulseAudioInput::open()
         qDebug() << "Frame size: " << pa_frame_size(&spec);
 #endif
 
-    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-    pa_threaded_mainloop_lock(pulseEngine->mainloop());
+    pulseEngine->lock();
     pa_channel_map channel_map;
 
     pa_channel_map_init_extend(&channel_map, spec.channels, PA_CHANNEL_MAP_DEFAULT);
 
-    if (!pa_channel_map_compatible(&channel_map, &spec)) {
+    if (!pa_channel_map_compatible(&channel_map, &spec))
         qWarning() << "Channel map doesn't match sample specification!";
-    }
 
     m_stream = pa_stream_new(pulseEngine->context(), m_streamName.constData(), &spec, &channel_map);
 
@@ -338,13 +319,16 @@ bool QPulseAudioInput::open()
 
     if (pa_stream_connect_record(m_stream, m_device.data(), &buffer_attr, (pa_stream_flags_t)flags) < 0) {
         qWarning() << "pa_stream_connect_record() failed!";
-        m_errorState = QAudio::FatalError;
+        pa_stream_unref(m_stream);
+        m_stream = 0;
+        pulseEngine->unlock();
+        setError(QAudio::OpenError);
+        setState(QAudio::StoppedState);
         return false;
     }
 
-    while (pa_stream_get_state(m_stream) != PA_STREAM_READY) {
+    while (pa_stream_get_state(m_stream) != PA_STREAM_READY)
         pa_threaded_mainloop_wait(pulseEngine->mainloop());
-    }
 
     const pa_buffer_attr *actualBufferAttr = pa_stream_get_buffer_attr(m_stream);
     m_periodSize = actualBufferAttr->fragsize;
@@ -352,14 +336,16 @@ bool QPulseAudioInput::open()
     if (actualBufferAttr->tlength != (uint32_t)-1)
         m_bufferSize = actualBufferAttr->tlength;
 
-    setPulseVolume();
+    pulseEngine->unlock();
 
-    pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+    connect(pulseEngine, &QPulseAudioEngine::contextFailed, this, &QPulseAudioInput::onPulseContextFailed);
 
     m_opened = true;
     m_timer->start(m_periodTime);
-    m_errorState = QAudio::NoError;
 
+    m_clockStamp.restart();
+    m_timeStamp.restart();
+    m_elapsedTimeOffset = 0;
     m_totalTimeValue = 0;
 
     return true;
@@ -367,21 +353,30 @@ bool QPulseAudioInput::open()
 
 void QPulseAudioInput::close()
 {
+    if (!m_opened)
+        return;
+
     m_timer->stop();
 
-    if (m_stream) {
-        QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-        pa_threaded_mainloop_lock(pulseEngine->mainloop());
+    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
 
+    if (m_stream) {
+        pulseEngine->lock();
+
+        pa_stream_set_state_callback(m_stream, 0, 0);
         pa_stream_set_read_callback(m_stream, 0, 0);
+        pa_stream_set_underflow_callback(m_stream, 0, 0);
+        pa_stream_set_overflow_callback(m_stream, 0, 0);
 
         pa_stream_disconnect(m_stream);
         pa_stream_unref(m_stream);
         m_stream = 0;
 
-        pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+        pulseEngine->unlock();
     }
 
+    disconnect(pulseEngine, &QPulseAudioEngine::contextFailed, this, &QPulseAudioInput::onPulseContextFailed);
+
     if (!m_pullMode && m_audioSource) {
         delete m_audioSource;
         m_audioSource = 0;
@@ -389,31 +384,6 @@ void QPulseAudioInput::close()
     m_opened = false;
 }
 
-/* Call this with the stream opened and the mainloop locked */
-void QPulseAudioInput::setPulseVolume()
-{
-    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-
-    pa_cvolume cvolume;
-
-    if (qFuzzyCompare(m_volume, 0.0)) {
-        pa_cvolume_mute(&cvolume, m_spec.channels);
-    } else {
-        pa_cvolume_set(&cvolume, m_spec.channels, pa_sw_volume_from_linear(m_volume));
-    }
-
-    pa_operation *op = pa_context_set_source_volume_by_index(pulseEngine->context(),
-            pa_stream_get_device_index(m_stream),
-            &cvolume,
-            inputVolumeCallback,
-            this);
-
-    if (op == NULL)
-        qWarning() << "QAudioInput: Failed to set volume";
-    else
-        pa_operation_unref(op);
-}
-
 int QPulseAudioInput::checkBytesReady()
 {
     if (m_deviceState != QAudio::ActiveState && m_deviceState != QAudio::IdleState) {
@@ -434,11 +404,8 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
 {
     m_bytesAvailable = checkBytesReady();
 
-    if (m_deviceState != QAudio::ActiveState) {
-        m_errorState = QAudio::NoError;
-        m_deviceState = QAudio::ActiveState;
-        emit stateChanged(m_deviceState);
-    }
+    setError(QAudio::NoError);
+    setState(QAudio::ActiveState);
 
     int readBytes = 0;
 
@@ -463,7 +430,8 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
 #endif
 
         QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-        pa_threaded_mainloop_lock(pulseEngine->mainloop());
+        pulseEngine->lock();
+
         const void *audioBuffer;
 
         // Second and third parameters (audioBuffer and length) to pa_stream_peek are output parameters,
@@ -471,26 +439,27 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
         // and the length is set to the length of this data.
         if (pa_stream_peek(m_stream, &audioBuffer, &readLength) < 0) {
             qWarning() << QString("pa_stream_peek() failed: %1").arg(pa_strerror(pa_context_errno(pa_stream_get_context(m_stream))));
-            pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+            pulseEngine->unlock();
             return 0;
         }
 
         qint64 actualLength = 0;
         if (m_pullMode) {
-            actualLength = m_audioSource->write(static_cast<const char *>(audioBuffer), readLength);
+            QByteArray adjusted(readLength, Qt::Uninitialized);
+            applyVolume(audioBuffer, adjusted.data(), readLength);
+            actualLength = m_audioSource->write(adjusted);
 
             if (actualLength < qint64(readLength)) {
-                pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+                pulseEngine->unlock();
 
-                m_errorState = QAudio::UnderrunError;
-                m_deviceState = QAudio::IdleState;
-                emit stateChanged(m_deviceState);
+                setError(QAudio::UnderrunError);
+                setState(QAudio::IdleState);
 
                 return actualLength;
             }
         } else {
             actualLength = qMin(static_cast<int>(len - readBytes), static_cast<int>(readLength));
-            memcpy(data + readBytes, audioBuffer, actualLength);
+            applyVolume(audioBuffer, data + readBytes, actualLength);
         }
 
 #ifdef DEBUG_PULSE
@@ -501,7 +470,10 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
 #ifdef DEBUG_PULSE
             qDebug() << "QPulseAudioInput::read -- appending " << readLength - actualLength << " bytes of data to temp buffer";
 #endif
-            m_tempBuffer.append(static_cast<const char *>(audioBuffer) + actualLength, readLength - actualLength);
+            int diff = readLength - actualLength;
+            int oldSize = m_tempBuffer.size();
+            m_tempBuffer.resize(m_tempBuffer.size() + diff);
+            applyVolume(static_cast<const char *>(audioBuffer) + actualLength, m_tempBuffer.data() + oldSize, diff);
             QMetaObject::invokeMethod(this, "userFeed", Qt::QueuedConnection);
         }
 
@@ -509,7 +481,7 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
         readBytes += actualLength;
 
         pa_stream_drop(m_stream);
-        pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+        pulseEngine->unlock();
 
         if (!m_pullMode && readBytes >= len)
             break;
@@ -528,56 +500,48 @@ qint64 QPulseAudioInput::read(char *data, qint64 len)
     return readBytes;
 }
 
+void QPulseAudioInput::applyVolume(const void *src, void *dest, int len)
+{
+    if (m_volume < 1.f)
+        QAudioHelperInternal::qMultiplySamples(m_volume, m_format, src, dest, len);
+    else
+        memcpy(dest, src, len);
+}
+
 void QPulseAudioInput::resume()
 {
     if (m_deviceState == QAudio::SuspendedState || m_deviceState == QAudio::IdleState) {
         QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
         pa_operation *operation;
 
-        pa_threaded_mainloop_lock(pulseEngine->mainloop());
+        pulseEngine->lock();
 
         operation = pa_stream_cork(m_stream, 0, inputStreamSuccessCallback, 0);
-
-        while (pa_operation_get_state(operation) == PA_OPERATION_RUNNING)
-            pa_threaded_mainloop_wait(pulseEngine->mainloop());
-
+        pulseEngine->wait(operation);
         pa_operation_unref(operation);
 
-        pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+        pulseEngine->unlock();
 
         m_timer->start(m_periodTime);
 
-        m_deviceState = QAudio::ActiveState;
-
-        emit stateChanged(m_deviceState);
+        setState(QAudio::ActiveState);
+        setError(QAudio::NoError);
     }
 }
 
 void QPulseAudioInput::setVolume(qreal vol)
 {
-    if (vol >= 0.0 && vol <= 1.0) {
-        QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-        pa_threaded_mainloop_lock(pulseEngine->mainloop());
-        if (!qFuzzyCompare(m_volume, vol)) {
-            m_volume = vol;
-            if (m_opened) {
-                setPulseVolume();
-            }
-        }
-        pa_threaded_mainloop_unlock(pulseEngine->mainloop());
-    }
+    if (qFuzzyCompare(m_volume, vol))
+        return;
+
+    m_volume = qBound(qreal(0), vol, qreal(1));
 }
 
 qreal QPulseAudioInput::volume() const
 {
-    QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
-    pa_threaded_mainloop_lock(pulseEngine->mainloop());
-    qreal vol = m_volume;
-    pa_threaded_mainloop_unlock(pulseEngine->mainloop());
-    return vol;
+    return m_volume;
 }
 
-
 void QPulseAudioInput::setBufferSize(int value)
 {
     m_bufferSize = value;
@@ -614,23 +578,21 @@ qint64 QPulseAudioInput::processedUSecs() const
 void QPulseAudioInput::suspend()
 {
     if (m_deviceState == QAudio::ActiveState) {
+        setError(QAudio::NoError);
+        setState(QAudio::SuspendedState);
+
         m_timer->stop();
-        m_deviceState = QAudio::SuspendedState;
-        emit stateChanged(m_deviceState);
 
         QPulseAudioEngine *pulseEngine = QPulseAudioEngine::instance();
         pa_operation *operation;
 
-        pa_threaded_mainloop_lock(pulseEngine->mainloop());
+        pulseEngine->lock();
 
         operation = pa_stream_cork(m_stream, 1, inputStreamSuccessCallback, 0);
-
-        while (pa_operation_get_state(operation) == PA_OPERATION_RUNNING)
-            pa_threaded_mainloop_wait(pulseEngine->mainloop());
-
+        pulseEngine->wait(operation);
         pa_operation_unref(operation);
 
-        pa_threaded_mainloop_unlock(pulseEngine->mainloop());
+        pulseEngine->unlock();
     }
 }
 
@@ -653,7 +615,7 @@ bool QPulseAudioInput::deviceReady()
     } else {
         // emits readyRead() so user will call read() on QIODevice to get some audio data
         if (m_audioSource != 0) {
-            InputPrivate *a = qobject_cast<InputPrivate*>(m_audioSource);
+            PulseInputPrivate *a = qobject_cast<PulseInputPrivate*>(m_audioSource);
             a->trigger();
         }
     }
@@ -676,7 +638,7 @@ qint64 QPulseAudioInput::elapsedUSecs() const
     if (m_deviceState == QAudio::StoppedState)
         return 0;
 
-    return m_clockStamp.elapsed() * 1000;
+    return m_clockStamp.elapsed() * qint64(1000);
 }
 
 void QPulseAudioInput::reset()
@@ -685,24 +647,32 @@ void QPulseAudioInput::reset()
     m_bytesAvailable = 0;
 }
 
-InputPrivate::InputPrivate(QPulseAudioInput *audio)
+void QPulseAudioInput::onPulseContextFailed()
+{
+    close();
+
+    setError(QAudio::FatalError);
+    setState(QAudio::StoppedState);
+}
+
+PulseInputPrivate::PulseInputPrivate(QPulseAudioInput *audio)
 {
     m_audioDevice = qobject_cast<QPulseAudioInput*>(audio);
 }
 
-qint64 InputPrivate::readData(char *data, qint64 len)
+qint64 PulseInputPrivate::readData(char *data, qint64 len)
 {
     return m_audioDevice->read(data, len);
 }
 
-qint64 InputPrivate::writeData(const char *data, qint64 len)
+qint64 PulseInputPrivate::writeData(const char *data, qint64 len)
 {
     Q_UNUSED(data)
     Q_UNUSED(len)
     return 0;
 }
 
-void InputPrivate::trigger()
+void PulseInputPrivate::trigger()
 {
     emit readyRead();
 }
