@@ -1,34 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd and/or its subsidiary(-ies).
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd and/or its subsidiary(-ies).
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -158,7 +161,7 @@ private:
         if (isDefault)
             defaultDeviceIndex = index;
 
-        foreach (QWinRTVideoDeviceSelectorControl *watcher, watchers)
+        for (QWinRTVideoDeviceSelectorControl *watcher : qAsConst(watchers))
             emit watcher->devicesChanged();
 
         return S_OK;
@@ -180,7 +183,7 @@ private:
         if (index >= 0)
             devices.remove(index);
 
-        foreach (QWinRTVideoDeviceSelectorControl *watcher, watchers)
+        for (QWinRTVideoDeviceSelectorControl *watcher : qAsConst(watchers))
             emit watcher->devicesChanged();
 
         return S_OK;
@@ -189,7 +192,7 @@ private:
     HRESULT onDeviceUpdated(IDeviceWatcher *, IDeviceInformationUpdate *)
     {
         // A name or description may have changed, so emit devicesChanged
-        foreach (QWinRTVideoDeviceSelectorControl *watcher, watchers)
+        for (QWinRTVideoDeviceSelectorControl *watcher : qAsConst(watchers))
             emit watcher->devicesChanged();
 
         return S_OK;
@@ -350,8 +353,9 @@ int QWinRTVideoDeviceSelectorControl::cameraOrientation(const QString &deviceNam
 QList<QByteArray> QWinRTVideoDeviceSelectorControl::deviceNames()
 {
     QList<QByteArray> devices;
-    foreach (const QString &device, g->deviceIndex.keys())
-        devices.append(device.toUtf8());
+    devices.reserve(g->deviceIndex.size());
+    for (auto it = g->deviceIndex.keyBegin(), end = g->deviceIndex.keyEnd(); it != end; ++it)
+        devices.append((*it).toUtf8());
 
     return devices;
 }
