@@ -1,32 +1,38 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Copyright (C) 2012 Research In Motion
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2016 Research In Motion
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -64,7 +70,8 @@ QDeclarativeVideoRendererBackend::QDeclarativeVideoRendererBackend(QDeclarativeV
     // Prioritize the plugin requested by the environment
     QString requestedVideoNode = QString::fromLatin1(qgetenv("QT_VIDEONODE"));
 
-    foreach (const QString &key, videoNodeFactoryLoader()->keys()) {
+    const auto keys = videoNodeFactoryLoader()->keys();
+    for (const QString &key : keys) {
         QObject *instance = videoNodeFactoryLoader()->instance(key);
         QSGVideoNodeFactoryInterface* plugin = qobject_cast<QSGVideoNodeFactoryInterface*>(instance);
         if (plugin) {
@@ -124,7 +131,7 @@ class FilterRunnableDeleter : public QRunnable
 public:
     FilterRunnableDeleter(const QList<QVideoFilterRunnable *> &runnables) : m_runnables(runnables) { }
     void run() Q_DECL_OVERRIDE {
-        foreach (QVideoFilterRunnable *runnable, m_runnables)
+        for (QVideoFilterRunnable *runnable : qAsConst(m_runnables))
             delete runnable;
     }
 private:
@@ -325,10 +332,17 @@ QSGNode *QDeclarativeVideoRendererBackend::updatePaintNode(QSGNode *oldNode,
         }
 
         if (!videoNode) {
-            foreach (QSGVideoNodeFactoryInterface* factory, m_videoNodeFactories) {
+            for (QSGVideoNodeFactoryInterface* factory : qAsConst(m_videoNodeFactories)) {
                 // Get a node that supports our frame. The surface is irrelevant, our
                 // QSGVideoItemSurface supports (logically) anything.
-                videoNode = factory->createNode(QVideoSurfaceFormat(m_frame.size(), m_frame.pixelFormat(), m_frame.handleType()));
+                QVideoSurfaceFormat nodeFormat(m_frame.size(), m_frame.pixelFormat(), m_frame.handleType());
+                const QVideoSurfaceFormat surfaceFormat = m_surface->surfaceFormat();
+                nodeFormat.setYCbCrColorSpace(surfaceFormat.yCbCrColorSpace());
+                nodeFormat.setPixelAspectRatio(surfaceFormat.pixelAspectRatio());
+                nodeFormat.setScanLineDirection(surfaceFormat.scanLineDirection());
+                nodeFormat.setViewport(surfaceFormat.viewport());
+                nodeFormat.setFrameRate(surfaceFormat.frameRate());
+                videoNode = factory->createNode(nodeFormat);
                 if (videoNode) {
                     qCDebug(qLcVideo) << "updatePaintNode: Video node created. Handle type:" << m_frame.handleType()
                                      << " Supported formats for the handle by this node:"
@@ -368,9 +382,9 @@ QAbstractVideoSurface *QDeclarativeVideoRendererBackend::videoSurface() const
 QRectF QDeclarativeVideoRendererBackend::adjustedViewport() const
 {
     const QRectF viewport = m_surface->surfaceFormat().viewport();
-    const QSize pixelAspectRatio = m_surface->surfaceFormat().pixelAspectRatio();
+    const QSizeF pixelAspectRatio = m_surface->surfaceFormat().pixelAspectRatio();
 
-    if (pixelAspectRatio.height() != 0) {
+    if (pixelAspectRatio.isValid()) {
         const qreal ratio = pixelAspectRatio.width() / pixelAspectRatio.height();
         QRectF result = viewport;
         result.setX(result.x() * ratio);
@@ -427,7 +441,7 @@ QList<QVideoFrame::PixelFormat> QSGVideoItemSurface::supportedPixelFormats(
             return formats;
     }
 
-    foreach (QSGVideoNodeFactoryInterface* factory, m_backend->m_videoNodeFactories)
+    for (QSGVideoNodeFactoryInterface* factory : qAsConst(m_backend->m_videoNodeFactories))
         formats.append(factory->supportedPixelFormats(handleType));
 
     return formats;
