@@ -53,7 +53,8 @@ QList<QVideoFrame::PixelFormat> QSGVideoNodeFactory_YUV::supportedPixelFormats(
 
     if (handleType == QAbstractVideoBuffer::NoHandle) {
         formats << QVideoFrame::Format_YUV420P << QVideoFrame::Format_YV12
-                << QVideoFrame::Format_NV12 << QVideoFrame::Format_NV21;
+                << QVideoFrame::Format_NV12 << QVideoFrame::Format_NV21
+                << QVideoFrame::Format_UYVY << QVideoFrame::Format_YUYV;
     }
 
     return formats;
@@ -78,9 +79,9 @@ public:
         setShaderSourceFile(QOpenGLShader::Fragment, QStringLiteral(":/qtmultimediaquicktools/shaders/biplanaryuvvideo.frag"));
     }
 
-    virtual void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial);
+    void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
 
-    virtual char const *const *attributeNames() const {
+    char const *const *attributeNames() const override {
         static const char *names[] = {
             "qt_VertexPosition",
             "qt_VertexTexCoord",
@@ -90,7 +91,7 @@ public:
     }
 
 protected:
-    virtual void initialize() {
+    void initialize() override {
         m_id_matrix = program()->uniformLocation("qt_Matrix");
         m_id_plane1Width = program()->uniformLocation("plane1Width");
         m_id_plane2Width = program()->uniformLocation("plane2Width");
@@ -109,6 +110,55 @@ protected:
     int m_id_opacity;
 };
 
+class QSGVideoMaterialShader_UYVY : public QSGMaterialShader
+{
+public:
+    QSGVideoMaterialShader_UYVY()
+        : QSGMaterialShader()
+    {
+        setShaderSourceFile(QOpenGLShader::Vertex, QStringLiteral(":/qtmultimediaquicktools/shaders/monoplanarvideo.vert"));
+        setShaderSourceFile(QOpenGLShader::Fragment, QStringLiteral(":/qtmultimediaquicktools/shaders/uyvyvideo.frag"));
+    }
+
+    void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) Q_DECL_OVERRIDE;
+
+    char const *const *attributeNames() const Q_DECL_OVERRIDE {
+        static const char *names[] = {
+            "qt_VertexPosition",
+            "qt_VertexTexCoord",
+            0
+        };
+        return names;
+    }
+
+protected:
+    void initialize() Q_DECL_OVERRIDE {
+        m_id_matrix = program()->uniformLocation("qt_Matrix");
+        m_id_yTexture = program()->uniformLocation("yTexture");
+        m_id_uvTexture = program()->uniformLocation("uvTexture");
+        m_id_colorMatrix = program()->uniformLocation("colorMatrix");
+        m_id_opacity = program()->uniformLocation("opacity");
+        QSGMaterialShader::initialize();
+    }
+
+    int m_id_matrix;
+    int m_id_yTexture;
+    int m_id_uvTexture;
+    int m_id_colorMatrix;
+    int m_id_opacity;
+};
+
+
+class QSGVideoMaterialShader_YUYV : public QSGVideoMaterialShader_UYVY
+{
+public:
+    QSGVideoMaterialShader_YUYV()
+        : QSGVideoMaterialShader_UYVY()
+    {
+        setShaderSourceFile(QOpenGLShader::Fragment, QStringLiteral(":/qtmultimediaquicktools/shaders/yuyvvideo.frag"));
+    }
+};
+
 
 class QSGVideoMaterialShader_YUV_BiPlanar_swizzle : public QSGVideoMaterialShader_YUV_BiPlanar
 {
@@ -131,10 +181,10 @@ public:
         setShaderSourceFile(QOpenGLShader::Fragment, QStringLiteral(":/qtmultimediaquicktools/shaders/triplanaryuvvideo.frag"));
     }
 
-    virtual void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial);
+    void updateState(const RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
 
 protected:
-    virtual void initialize() {
+    void initialize() override {
         m_id_plane3Width = program()->uniformLocation("plane3Width");
         m_id_plane3Texture = program()->uniformLocation("plane3Texture");
         QSGVideoMaterialShader_YUV_BiPlanar::initialize();
@@ -151,31 +201,39 @@ public:
     QSGVideoMaterial_YUV(const QVideoSurfaceFormat &format);
     ~QSGVideoMaterial_YUV();
 
-    virtual QSGMaterialType *type() const {
-        static QSGMaterialType biPlanarType, biPlanarSwizzleType, triPlanarType;
+    QSGMaterialType *type() const override {
+        static QSGMaterialType biPlanarType, biPlanarSwizzleType, triPlanarType, uyvyType, yuyvType;
 
         switch (m_format.pixelFormat()) {
         case QVideoFrame::Format_NV12:
             return &biPlanarType;
         case QVideoFrame::Format_NV21:
             return &biPlanarSwizzleType;
+        case QVideoFrame::Format_UYVY:
+            return &uyvyType;
+        case QVideoFrame::Format_YUYV:
+            return &yuyvType;
         default: // Currently: YUV420P and YV12
             return &triPlanarType;
         }
     }
 
-    virtual QSGMaterialShader *createShader() const {
+    QSGMaterialShader *createShader() const override {
         switch (m_format.pixelFormat()) {
         case QVideoFrame::Format_NV12:
             return new QSGVideoMaterialShader_YUV_BiPlanar;
         case QVideoFrame::Format_NV21:
             return new QSGVideoMaterialShader_YUV_BiPlanar_swizzle;
+        case QVideoFrame::Format_UYVY:
+            return new QSGVideoMaterialShader_UYVY;
+        case QVideoFrame::Format_YUYV:
+            return new QSGVideoMaterialShader_YUYV;
         default: // Currently: YUV420P and YV12
             return new QSGVideoMaterialShader_YUV_TriPlanar;
         }
     }
 
-    virtual int compare(const QSGMaterial *other) const {
+    int compare(const QSGMaterial *other) const override {
         const QSGVideoMaterial_YUV *m = static_cast<const QSGVideoMaterial_YUV *>(other);
         if (!m_textureIds[0])
             return 1;
@@ -230,8 +288,10 @@ QSGVideoMaterial_YUV::QSGVideoMaterial_YUV(const QVideoSurfaceFormat &format) :
     case QVideoFrame::Format_YV12:
         m_planeCount = 3;
         break;
+    case QVideoFrame::Format_UYVY:
+    case QVideoFrame::Format_YUYV:
     default:
-        m_planeCount = 1;
+        m_planeCount = 2;
         break;
     }
 
@@ -293,7 +353,22 @@ void QSGVideoMaterial_YUV::bind()
             functions->glGetIntegerv(GL_UNPACK_ALIGNMENT, &previousAlignment);
             functions->glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
 
-            if (m_format.pixelFormat() == QVideoFrame::Format_NV12
+             if (m_format.pixelFormat() == QVideoFrame::Format_UYVY
+              || m_format.pixelFormat() == QVideoFrame::Format_YUYV) {
+                int fw = m_frame.width();
+                m_planeWidth[0] = fw;
+                 // In YUYV texture the UV plane appears with the 1/2 of image and Y width.
+                m_planeWidth[1] = fw / 2;
+                functions->glActiveTexture(GL_TEXTURE1);
+                // Either r,b (YUYV) or g,a (UYVY) values are used as source of YV.
+                // Additionally Y and V are set per 2 pixels hence only 1/2 of image with is used.
+                // Interpreting this properly in shaders allows to not copy or not make conditionals inside shaders,
+                // only interpretation of data changes.
+                bindTexture(m_textureIds[1], m_planeWidth[1], m_frame.height(), m_frame.bits(), GL_RGBA);
+                functions->glActiveTexture(GL_TEXTURE0); // Finish with 0 as default texture unit
+                // Either red (YUYV) or alpha (UYVY) values are used as source of Y
+                bindTexture(m_textureIds[0], m_planeWidth[0], m_frame.height(), m_frame.bits(), GL_LUMINANCE_ALPHA);
+            } else if (m_format.pixelFormat() == QVideoFrame::Format_NV12
                     || m_format.pixelFormat() == QVideoFrame::Format_NV21) {
                 const int y = 0;
                 const int uv = 1;
@@ -338,7 +413,6 @@ void QSGVideoMaterial_YUV::bind()
 void QSGVideoMaterial_YUV::bindTexture(int id, int w, int h, const uchar *bits, GLenum format)
 {
     QOpenGLFunctions *functions = QOpenGLContext::currentContext()->functions();
-
     functions->glBindTexture(GL_TEXTURE_2D, id);
     functions->glTexImage2D(GL_TEXTURE_2D, 0, format, w, h, 0, format, GL_UNSIGNED_BYTE, bits);
     functions->glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -399,4 +473,27 @@ void QSGVideoMaterialShader_YUV_TriPlanar::updateState(const RenderState &state,
     program()->setUniformValue(m_id_plane3Width, mat->m_planeWidth[2]);
 }
 
+void QSGVideoMaterialShader_UYVY::updateState(const RenderState &state,
+                                                       QSGMaterial *newMaterial,
+                                                       QSGMaterial *oldMaterial)
+{
+    Q_UNUSED(oldMaterial);
+
+    QSGVideoMaterial_YUV *mat = static_cast<QSGVideoMaterial_YUV *>(newMaterial);
+    program()->setUniformValue(m_id_yTexture, 0);
+    program()->setUniformValue(m_id_uvTexture, 1);
+
+    mat->bind();
+
+    program()->setUniformValue(m_id_colorMatrix, mat->m_colorMatrix);
+
+    if (state.isOpacityDirty()) {
+        mat->m_opacity = state.opacity();
+        program()->setUniformValue(m_id_opacity, GLfloat(mat->m_opacity));
+    }
+
+    if (state.isMatrixDirty())
+        program()->setUniformValue(m_id_matrix, state.combinedMatrix());
+}
+
 QT_END_NAMESPACE
