@@ -59,6 +59,7 @@ private slots:
     void construction();
     void loadMedia();
     void unloadMedia();
+    void loadMediaInLoadingState();
     void playPauseStop();
     void processEOS();
     void deleteLaterAtEOS();
@@ -221,7 +222,9 @@ void tst_QMediaPlayerBackend::initTestCase()
 
     QStringList mediaCandidates;
     mediaCandidates << QFINDTESTDATA("testdata/colors.mp4");
+#ifndef SKIP_OGV_TEST
     mediaCandidates << QFINDTESTDATA("testdata/colors.ogv");
+#endif
     localVideoFile = selectMediaFile(mediaCandidates);
 
     mediaCandidates.clear();
@@ -323,6 +326,16 @@ void tst_QMediaPlayerBackend::unloadMedia()
     QVERIFY(!positionSpy.isEmpty());
 }
 
+void tst_QMediaPlayerBackend::loadMediaInLoadingState()
+{
+    const QUrl url("http://unavailable.media/");
+    QMediaPlayer player;
+    player.setMedia(QMediaContent(url));
+    player.play();
+    // Sets new media while old has not been finished.
+    player.setMedia(QMediaContent(url));
+    QTRY_COMPARE(player.mediaStatus(), QMediaPlayer::InvalidMedia);
+}
 
 void tst_QMediaPlayerBackend::playPauseStop()
 {
@@ -382,7 +395,9 @@ void tst_QMediaPlayerBackend::playPauseStop()
 
     stateSpy.clear();
     statusSpy.clear();
+    positionSpy.clear();
 
+    qint64 positionBeforePause = player.position();
     player.pause();
 
     QCOMPARE(player.state(), QMediaPlayer::PausedState);
@@ -391,6 +406,11 @@ void tst_QMediaPlayerBackend::playPauseStop()
     QCOMPARE(stateSpy.count(), 1);
     QCOMPARE(stateSpy.last()[0].value<QMediaPlayer::State>(), QMediaPlayer::PausedState);
 
+    QTest::qWait(2000);
+
+    QVERIFY(qAbs(player.position() - positionBeforePause) < 100);
+    QCOMPARE(positionSpy.count(), 0);
+
     stateSpy.clear();
     statusSpy.clear();
 
@@ -541,6 +561,32 @@ void tst_QMediaPlayerBackend::processEOS()
     QCOMPARE(stateSpy.count(), 0);
     QTRY_VERIFY(statusSpy.count() > 0 &&
         statusSpy.last()[0].value<QMediaPlayer::MediaStatus>() == QMediaPlayer::LoadedMedia);
+
+    player.play();
+    player.setPosition(900);
+    //wait up to 5 seconds for EOS
+    QTRY_COMPARE(player.mediaStatus(), QMediaPlayer::EndOfMedia);
+    QCOMPARE(player.state(), QMediaPlayer::StoppedState);
+    QCOMPARE(player.position(), player.duration());
+
+    stateSpy.clear();
+    statusSpy.clear();
+    positionSpy.clear();
+
+    // pause() should reset position to beginning and status to Buffered
+    player.pause();
+
+    QTRY_COMPARE(player.position(), 0);
+    QTRY_VERIFY(positionSpy.count() > 0);
+    QCOMPARE(positionSpy.first()[0].value<qint64>(), 0);
+
+    QCOMPARE(player.state(), QMediaPlayer::PausedState);
+    QTRY_COMPARE(player.mediaStatus(), QMediaPlayer::BufferedMedia);
+
+    QCOMPARE(stateSpy.count(), 1);
+    QCOMPARE(stateSpy.last()[0].value<QMediaPlayer::State>(), QMediaPlayer::PausedState);
+    QVERIFY(statusSpy.count() > 0);
+    QCOMPARE(statusSpy.last()[0].value<QMediaPlayer::MediaStatus>(), QMediaPlayer::BufferedMedia);
 }
 
 // Helper class for tst_QMediaPlayerBackend::deleteLaterAtEOS()
@@ -749,6 +795,10 @@ void tst_QMediaPlayerBackend::seekPauseSeek()
     QTRY_COMPARE(player.state(), QMediaPlayer::PausedState); // it might take some time for the operation to be completed
     QTRY_VERIFY(!surface->m_frameList.isEmpty()); // we must see a frame at position 7000 here
 
+    // Make sure that the frame has a timestamp before testing - not all backends provides this
+    if (surface->m_frameList.back().startTime() < 0)
+        QSKIP("No timestamp");
+
     {
         QVideoFrame frame = surface->m_frameList.back();
         const qint64 elapsed = (frame.startTime() / 1000) - position; // frame.startTime() is microsecond, position is milliseconds.
@@ -1301,7 +1351,9 @@ void tst_QMediaPlayerBackend::surfaceTest_data()
     formatsYUV << QVideoFrame::Format_YUV420P
                << QVideoFrame::Format_YV12
                << QVideoFrame::Format_UYVY
-               << QVideoFrame::Format_YUYV;
+               << QVideoFrame::Format_YUYV
+               << QVideoFrame::Format_NV12
+               << QVideoFrame::Format_NV21;
 
     QTest::newRow("RGB formats")
             << formatsRGB;
@@ -1328,7 +1380,9 @@ void tst_QMediaPlayerBackend::surfaceTest()
     player.setMedia(localVideoFile);
     player.play();
     QTRY_VERIFY(player.position() >= 1000);
-    QVERIFY(surface.m_totalFrames >= 25);
+    if (surface.error() == QAbstractVideoSurface::UnsupportedFormatError)
+        QSKIP("None of the pixel formats is supported by the backend");
+    QVERIFY2(surface.m_totalFrames >= 25, qPrintable(QString("Expected >= 25, got %1").arg(surface.m_totalFrames)));
 }
 
 void tst_QMediaPlayerBackend::metadata()
@@ -1388,7 +1442,10 @@ QList<QVideoFrame::PixelFormat> TestVideoSurface::supportedPixelFormats(
 
 bool TestVideoSurface::start(const QVideoSurfaceFormat &format)
 {
-    if (!isFormatSupported(format)) return false;
+    if (!isFormatSupported(format)) {
+        setError(UnsupportedFormatError);
+        return false;
+    }
 
     return QAbstractVideoSurface::start(format);
 }
